@@ -1,10 +1,11 @@
 #ifndef _TYPEDEFS_H_
 #define _TYPEDEFS_H_
 /******** Definition of items with uniquely size **********
-(c) 1997-2023 Jaroslav Fojtik
+(c) 1997-2024 Jaroslav Fojtik
    if you don't use below mentionted compiler, please correct this items
    for your compiler and send me your correction to:
-			fojtik@penguin.cz or JaFojtik@yandex.com
+		JaFojtik@seznam.cz or JaFojtik@yandex.com
+* Licency: LGPL
 
 List of supported types:
 
@@ -12,7 +13,7 @@ List of supported types:
    -----+---------+------+---------------------
    uint8_t    BYTE   1 byte  =  8 bit
    int8_t    SBYTE   1 byte  =  8 bit signed
-   __u16      WORD   2 bytes = 16 bit
+   uint16_t   WORD   2 bytes = 16 bit
    int16_t   SWORD   2 bytes = 16 bit signed
    uint32_t  DWORD   4 bytes = 32 bit
    int32_t  SDWORD   4 bytes = 32 bit signed
@@ -157,6 +158,7 @@ extern "C" {
 
  #if _MSC_VER >= 1600
   #define HAS_STDINT_H
+  #define uint64_t_defined
  #else
   #if _MSC_VER > 1200
    #define  int64_t __int64
@@ -260,6 +262,12 @@ void ST_FLOAT_SWAP(void *b, float f);
   #ifdef LD_UINT32_SWAP
    #define LD_UINT32_HI(ptr)	LD_UINT32_SWAP(ptr)
   #endif
+  #ifdef ST_UINT16_SWAP
+   #define ST_UINT16_HI(ptr,val) ST_UINT16_SWAP(ptr,val)
+  #endif
+  #ifdef ST_UINT32_SWAP
+   #define ST_UINT32_HI(ptr,val) ST_UINT32_SWAP(ptr,val)
+  #endif
   #if defined(uint64_t_defined)
    #ifdef LD_UINT64_SWAP
     #define LD_UINT64_HI(ptr)	LD_UINT64_SWAP(ptr)
@@ -302,6 +310,60 @@ void ST_FLOAT_SWAP(void *b, float f);
 
 
 	/* Safe replacements for non native access. */
+#ifdef __cplusplus
+
+#ifndef LD_UINT16_LO
+ inline uint16_t LD_UINT16_LO(const void *ptr) {return (uint16_t)(((uint16_t)*(((uint8_t*)ptr)+1)<<8)|(uint16_t)*(uint8_t*)(ptr));}
+#endif
+#ifndef LD_UINT32_LO
+ inline uint32_t LD_UINT32_LO(const void *ptr) {return (uint32_t)(((uint32_t)*((uint8_t*)(ptr)+3)<<24)|((uint32_t)*((uint8_t*)(ptr)+2)<<16)|((uint16_t)*((uint8_t*)(ptr)+1)<<8)|*(uint8_t*)(ptr));}
+#endif
+#ifndef ST_UINT16_LO
+ inline void ST_UINT16_LO(void *ptr, const uint16_t val) {*(uint8_t*)(ptr)=(uint8_t)(val); *((uint8_t*)(ptr)+1)=(uint8_t)((uint16_t)(val)>>8);}
+#endif
+#ifndef ST_UINT32_LO
+ inline void ST_UINT32_LO(void *ptr, const uint32_t val) {*(uint8_t*)(ptr)=(uint8_t)(val); *((uint8_t*)(ptr)+1)=(uint8_t)((uint16_t)(val)>>8); *((uint8_t*)(ptr)+2)=(uint8_t)((uint32_t)(val)>>16); *((uint8_t*)(ptr)+3)=(uint8_t)((uint32_t)(val)>>24);};
+#endif
+
+#if defined(uint64_t_defined)
+ #ifndef LD_UINT64_LO
+   inline uint64_t LD_UINT64_LO(const void *ptr)
+   {return (uint64_t)((((uint64_t)*((uint8_t*)(ptr)+7)<<56) | ((uint64_t)*((uint8_t*)(ptr)+6)<<48) | ((uint64_t)*((uint8_t*)(ptr)+5)<<40) | ((uint64_t)*((uint8_t*)(ptr)+4)<<32) | ((uint32_t)*((uint8_t*)(ptr)+3)<<24) | ((uint32_t)*((uint8_t*)(ptr)+2)<<16) | ((uint16_t)*((uint8_t*)(ptr)+1)<<8) | *(uint8_t*)(ptr)));}
+ #endif
+ #ifndef ST_UINT64_LO
+  inline void ST_UINT64_LO(void *ptr, const uint64_t val)
+  {*(uint8_t*)(ptr)=(uint8_t)(val); *((uint8_t*)(ptr)+1)=(uint8_t)((uint16_t)(val)>>8); *((uint8_t*)(ptr)+2)=(uint8_t)((uint32_t)(val)>>16); *((uint8_t*)(ptr)+3)=(uint8_t)((uint32_t)(val)>>24); *((uint8_t*)(ptr)+4)=(uint8_t)((uint64_t)(val)>>32); *((uint8_t*)(ptr)+5)=(uint8_t)((uint64_t)(val)>>40); *((uint8_t*)(ptr)+6)=(uint8_t)((uint64_t)(val)>>48); *((uint8_t*)(ptr)+7)=(uint8_t)((uint64_t)(val)>>56);}
+ #endif
+#endif
+
+
+#ifndef LD_UINT16_HI
+  inline uint16_t LD_UINT16_HI(const void *ptr) {return (uint16_t)(((uint16_t)*(uint8_t*)((ptr))<<8)|(uint16_t)*((uint8_t*)(ptr)+1));}
+#endif
+#ifndef LD_UINT32_HI
+ inline uint32_t LD_UINT32_HI(const void *ptr) {return (uint32_t)(((uint32_t)*(uint8_t*)((ptr))<<24)|((uint32_t)*((uint8_t*)(ptr)+1)<<16)|((uint16_t)*((uint8_t*)(ptr)+2)<<8)|*((uint8_t*)(ptr)+3));}
+#endif
+#ifndef ST_UINT16_HI
+ inline void ST_UINT16_HI(void *ptr, const uint16_t val) {*((uint8_t*)(ptr)+1)=(uint8_t)(val); *(uint8_t*)((ptr))=(uint8_t)((uint16_t)(val)>>8);}
+#endif
+#ifndef ST_UINT32_HI
+ inline void ST_UINT32_HI(void *ptr, const uint32_t val) {*((uint8_t*)(ptr)+3)=(uint8_t)(val); *((uint8_t*)(ptr)+2)=(uint8_t)((uint16_t)(val)>>8); *((uint8_t*)(ptr)+1)=(uint8_t)((uint32_t)(val)>>16); *(uint8_t*)((ptr))=(uint8_t)((uint32_t)(val)>>24);}
+#endif
+
+#if defined(uint64_t_defined)
+ #ifndef LD_UINT64_HI
+  inline uint64_t LD_UINT64_HI(const void *ptr)
+  {return (uint64_t)( ((uint64_t)*(uint8_t*)(ptr)<<56) | ((uint64_t)*((uint8_t*)(ptr)+1)<<48) | ((uint64_t)*((uint8_t*)(ptr)+2)<<40) | ((uint64_t)*((uint8_t*)(ptr)+3)<<32) | ((uint32_t)*((uint8_t*)(ptr)+4)<<24)|((uint32_t)*((uint8_t*)(ptr)+5)<<16) | ((uint16_t)*((uint8_t*)(ptr)+6)<<8) | *((uint8_t*)(ptr)+7) );}
+ #endif
+ #ifndef ST_UINT64_HI
+  inline void ST_UINT64_HI(void *ptr, const uint64_t val)
+  {*((uint8_t*)(ptr)+7)=(uint8_t)(val); *((uint8_t*)(ptr)+6)=(uint8_t)((uint16_t)(val)>>8); *((uint8_t*)(ptr)+5)=(uint8_t)((uint32_t)(val)>>16); *((uint8_t*)(ptr)+4)=(uint8_t)((uint32_t)(val)>>24); *((uint8_t*)(ptr)+3)=(uint8_t)((uint64_t)(val)>>32); *((uint8_t*)(ptr)+2)=(uint8_t)((uint64_t)(val)>>40); *((uint8_t*)(ptr)+1)=(uint8_t)((uint64_t)(val)>>48); *(uint8_t*)((ptr))=(uint8_t)((uint64_t)(val)>>56);}
+ #endif
+#endif
+
+
+#else
+
 #ifndef LD_UINT16_LO
  #define LD_UINT16_LO(ptr)	(uint16_t)(((uint16_t)*(uint8_t*)((ptr)+1)<<8)|(uint16_t)*(uint8_t*)(ptr))
 #endif
@@ -325,7 +387,6 @@ void ST_FLOAT_SWAP(void *b, float f);
 #endif
 
 
-
 #ifndef LD_UINT16_HI
 #define LD_UINT16_HI(ptr)	(uint16_t)(((uint16_t)*(uint8_t*)((ptr))<<8)|(uint16_t)*((uint8_t*)(ptr)+1))
 #endif
@@ -349,6 +410,9 @@ void ST_FLOAT_SWAP(void *b, float f);
 #endif
 
 
+#endif
+
+
 	/* Use byte-by-byte access to structures */
 #define LD_UINT16(ptr)		LD_UINT16_LO(ptr)
 #define LD_UINT32(ptr)		LD_UINT32_LO(ptr)
