@@ -11,7 +11,7 @@
 #include <stdio.h>
 
 #include "typedfs.h"
-#include <sets.h>
+#include "sets.h"
 
 
 // Constructors of set class.
@@ -630,25 +630,26 @@ set &set::operator^=(int number)
 }
 
 
-/*This function verifies whether the given set is empty - faster than card()*/
-int EmptyCheck(const set &s)
+/** This function verifies whether the given set is empty - faster than card(). */
+int set::isEmpty(void) const
 {
 int size;
 uint16_t *CheckedData;
 
- size=(s.MaxElement-s.MinElement+1)>>4;
- if(s.data==NULL) return(1);
+   size=(MaxElement-MinElement+1)>>4;
+   if(data==NULL) return(1);
 
- CheckedData=s.data;
- while(size-->0)
+   CheckedData = data;
+   while(size-->0)
 	{
 	if(*CheckedData++!=0) return(0);  // set is not empty
 	};
- return(1);
+   return(1);
 }
 
 
-char *int2str(char *str,int i)
+/** Converts integer to string and return a pointer the the last character written. */
+char *int2str(char *str, int i)
 {
 int q,qq;
 char c;
