@@ -144,7 +144,7 @@ int i;
   for(i=1; i<=Card(s); i++)
 	{
 	if(i>1) xout<<',';
-	xout << s[i];
+	xout << s.data[i];
 	}
   xout << '}';
 return xout;
