@@ -1,9 +1,9 @@
 /*************************************************************************
-* unit:    struct            release 0.13                                *
+* unit:    struct            release 0.14                                *
 *   struct.c - Provides some big and little endian abstraction functions,
 *	      for manipulating with structures.
 * Licency: GPL or LGPL                                                   *
-*   Copyright (C) 1999-2022  Jaroslav Fojtik
+*   Copyright (C) 1999-2023  Jaroslav Fojtik
 **************************************************************************/
 #include <stdio.h>
 #include <stdarg.h>
@@ -14,8 +14,8 @@
 
 #include "struct.h"
 
-#ifdef QWORD
- #define QWORD_ QWORD
+#if defined(uint64_t) || defined(uint64_t_defined)
+ #define QWORD_ uint64_t
 #else
  #define QWORD_ double
 #endif
@@ -34,8 +34,8 @@
 
 #ifndef BYTESWAP_uint64
  #define BYTESWAP_uint64(__pval) \
-	BYTE n; \
-	BYTE *x = (BYTE *)&__pval; \
+	uint8_t n; \
+	uint8_t *x = (uint8_t *)&__pval; \
 	n=x[0]; x[0]=x[7]; x[7]=n; \
 	n=x[1]; x[1]=x[6]; x[6]=n; \
 	n=x[2]; x[2]=x[5]; x[5]=n; \
@@ -54,8 +54,8 @@
 #ifndef RdWORD_LoEnd
 /* Read a word from binary file in a LowEndian Format into a current endian.
  * parameters: FILE  *f :  binary input file
- * return:     WORD *num : readed word  */
-int RdWORD_LoEnd(WORD *num, FILE *f)
+ * return:     uint16_t *num : readed word  */
+int RdWORD_LoEnd(uint16_t *num, FILE *f)
 {
 #ifdef LO_ENDIAN
   return(fread(num,1,2,f));
@@ -67,8 +67,8 @@ return ret;
 #endif
 #if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
 unsigned char b;
-  if(!fread( &b, 1,1,f)) return 0; *num=(WORD)b;
-  if(!fread( &b, 1,1,f)) return 1; *num+=(WORD)b * 256l;
+  if(!fread( &b, 1,1,f)) return 0; *num=(uint16_t)b;
+  if(!fread( &b, 1,1,f)) return 1; *num+=(uint16_t)b * 256l;
 return 2;
 #endif
 }
@@ -78,8 +78,8 @@ return 2;
 #ifndef RdDWORD_LoEnd
 /* Read a double word from binary file in a LowEndian Format into a current endian.
  * parameters: FILE  *f :  binary input file
- * return:     DWORD *num : readed double word  */
-int RdDWORD_LoEnd(DWORD *num, FILE *f)
+ * return:     uint32_t *num : readed double word  */
+int RdDWORD_LoEnd(uint32_t *num, FILE *f)
 {
 #ifdef LO_ENDIAN
   return(fread(num,1,4,f));
@@ -91,10 +91,10 @@ return i;
 #endif
 #if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
 unsigned char b;
-  if(!fread( &b, 1,1,f)) return 0; *num=(DWORD)b;
-  if(!fread( &b, 1,1,f)) return 1; *num+=(DWORD)b * 256l;
-  if(!fread( &b, 1,1,f)) return 2; *num+=(DWORD)b * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 3; *num+=(DWORD)b * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 0; *num=(uint32_t)b;
+  if(!fread( &b, 1,1,f)) return 1; *num+=(uint32_t)b * 256l;
+  if(!fread( &b, 1,1,f)) return 2; *num+=(uint32_t)b * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 3; *num+=(uint32_t)b * 256l * 256l * 256l;
 return 4;
 #endif
 }
@@ -116,7 +116,7 @@ const int i = fread(num,1,8,f);
 return i;
 #endif
 #if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
-BYTE b;
+uint8_t b;
   if(!fread( &b, 1,1,f)) return 0; *num=(QWORD_)b;
   if(!fread( &b, 1,1,f)) return 1; *num+=(QWORD_)b * 256l;
   if(!fread( &b, 1,1,f)) return 2; *num+=(QWORD_)b * 256l * 256l;
@@ -134,8 +134,8 @@ return 8;
 #ifndef RdWORD_HiEnd
 /* Read a word from binary file in a HiEndian Format
  * parameters: FILE  *f :  binary input file
- * return:     WORD *num : readed word  */
-int RdWORD_HiEnd(WORD *num, FILE *f)
+ * return:     uint16_t *num : readed word  */
+int RdWORD_HiEnd(uint16_t *num, FILE *f)
 {
 #ifdef LO_ENDIAN
 int ret = fread(num,1,2,f);
@@ -148,8 +148,8 @@ return ret;
 #if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
 		//endian invariant
 unsigned char b;
-  if(!fread(&b,1,1,f)) return 0; *num=(WORD)b * 256l;
-  if(!fread(&b,1,1,f)) return 1; *num+=(WORD)b;
+  if(!fread(&b,1,1,f)) return 0; *num=(uint16_t)b * 256l;
+  if(!fread(&b,1,1,f)) return 1; *num+=(uint16_t)b;
 return 2;
 #endif
 }
@@ -159,8 +159,8 @@ return 2;
 #ifndef RdDWORD_HiEnd
 /* Read a double word from binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
- * return:     DWORD *num : readed double word  */
-int RdDWORD_HiEnd(DWORD *num, FILE *f)
+ * return:     uint32_t *num : readed double word  */
+int RdDWORD_HiEnd(uint32_t *num, FILE *f)
 {
 #ifdef LO_ENDIAN
 const int i = fread(num,1,4,f);
@@ -172,11 +172,11 @@ return i;
 #endif
 #if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
 		//endian invariant
-BYTE b;
-  if(!fread( &b, 1,1,f)) return 0; *num=(DWORD)b * 256l * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 1; *num+=(DWORD)b * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 2; *num+=(DWORD)b * 256l;
-  if(!fread( &b, 1,1,f)) return 3; *num+=(DWORD)b;
+uint8_t b;
+  if(!fread( &b, 1,1,f)) return 0; *num=(uint32_t)b * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 1; *num+=(uint32_t)b * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 2; *num+=(uint32_t)b * 256l;
+  if(!fread( &b, 1,1,f)) return 3; *num+=(uint32_t)b;
 return 4;
 #endif
 }
@@ -186,7 +186,7 @@ return 4;
 #ifndef RdQWORD_HiEnd
 /* Read a quad word from binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
- * return:     DWORD *num : readed double word  */
+ * return:     uint32_t *num : readed double word  */
 int RdQWORD_HiEnd(QWORD_ *num, FILE *f)
 {
 #ifdef LO_ENDIAN
@@ -199,15 +199,15 @@ return i;
 #endif
 #if !defined(LO_ENDIAN) && !defined(HI_ENDIAN)
 		//endian invariant
-BYTE b;
-  if(!fread( &b, 1,1,f)) return 0; *num=(DWORD)b  * 256l * 256l * 256l * 256l * 256l * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 1; *num+=(DWORD)b * 256l * 256l * 256l * 256l * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 2; *num+=(DWORD)b * 256l * 256l * 256l * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 3; *num+=(DWORD)b * 256l * 256l * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 4; *num+=(DWORD)b * 256l * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 5; *num+=(DWORD)b * 256l * 256l;
-  if(!fread( &b, 1,1,f)) return 6; *num+=(DWORD)b * 256l;
-  if(!fread( &b, 1,1,f)) return 7; *num+=(DWORD)b;
+uint8_t b;
+  if(!fread( &b, 1,1,f)) return 0; *num=(uint32_t)b  * 256l * 256l * 256l * 256l * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 1; *num+=(uint32_t)b * 256l * 256l * 256l * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 2; *num+=(uint32_t)b * 256l * 256l * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 3; *num+=(uint32_t)b * 256l * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 4; *num+=(uint32_t)b * 256l * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 5; *num+=(uint32_t)b * 256l * 256l;
+  if(!fread( &b, 1,1,f)) return 6; *num+=(uint32_t)b * 256l;
+  if(!fread( &b, 1,1,f)) return 7; *num+=(uint32_t)b;
   return 8;
 #endif
 }
@@ -218,15 +218,15 @@ BYTE b;
 #ifndef WrWORD_LoEnd
 /* Write a word to the binary file in a LowEndian Format
  * parameters: FILE  *f :  binary input file
- *             WORD num : word to be written */
-int WrWORD_LoEnd(WORD num, FILE *f)
+ *             uint16_t num : word to be written */
+int WrWORD_LoEnd(uint16_t num, FILE *f)
 {
 #ifdef LO_ENDIAN
   return(fwrite(&num,1,2,f));
 #else
-BYTE b;
-  b = (BYTE)((num >> 8*0) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 0;
-  b = (BYTE)((num >> 8*1) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 1;
+uint8_t b;
+  b = (uint8_t)((num >> 8*0) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 0;
+  b = (uint8_t)((num >> 8*1) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 1;
 return 2;
 #endif
 }
@@ -236,8 +236,8 @@ return 2;
 #ifndef WrDWORD_LoEnd
 /* Write a double word to the binary file in a LowEndian Format
  * parameters: FILE  *f :  binary input file
- *             DWORD num : double word to be written */
-int WrDWORD_LoEnd(DWORD num, FILE *f)
+ *             uint32_t num : double word to be written */
+int WrDWORD_LoEnd(uint32_t num, FILE *f)
 {
 #ifdef LO_ENDIAN
   return(fwrite(&num,1,4,f));
@@ -246,11 +246,11 @@ int WrDWORD_LoEnd(DWORD num, FILE *f)
   BYTESWAP_uint32(num);
   return(fwrite(&num,1,4,f));
 #else
-BYTE b;
-  b = (BYTE)((num >> 8*0) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 0;
-  b = (BYTE)((num >> 8*1) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 1;
-  b = (BYTE)((num >> 8*2) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 2;
-  b = (BYTE)((num >> 8*3) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 3;
+uint8_t b;
+  b = (uint8_t)((num >> 8*0) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 0;
+  b = (uint8_t)((num >> 8*1) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 1;
+  b = (uint8_t)((num >> 8*2) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 2;
+  b = (uint8_t)((num >> 8*3) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 3;
 return 4;
 #endif
 #endif
@@ -261,15 +261,15 @@ return 4;
 #ifndef WrWORD_HiEnd
 /* Write a word to the binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
- *             WORD num : word to be written */
-int WrWORD_HiEnd(WORD num, FILE *f)
+ *             uint16_t num : word to be written */
+int WrWORD_HiEnd(uint16_t num, FILE *f)
 {
 #ifdef HI_ENDIAN
   return(fwrite(&num,1,2,f));
 #else
-BYTE b;
-  b = (BYTE)((num >> 8*1) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 0;
-  b = (BYTE)((num >> 8*0) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 1;
+uint8_t b;
+  b = (uint8_t)((num >> 8*1) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 0;
+  b = (uint8_t)((num >> 8*0) & 0x00ffl); if(!fwrite( &b, 1,1,f)) return 1;
 return 2;
 #endif
 }
@@ -279,8 +279,8 @@ return 2;
 #ifndef WrDWORD_HiEnd
 /* Write a double word to the binary file in a HiEndian Format
  * parameters: FILE  *f :  binary input file
- *             DWORD num : double word to be written */
-int WrDWORD_HiEnd(DWORD num, FILE *f)
+ *             uint32_t num : double word to be written */
+int WrDWORD_HiEnd(uint32_t num, FILE *f)
 {
 #ifdef HI_ENDIAN
   return(fwrite(&num,1,4,f));
@@ -289,11 +289,11 @@ int WrDWORD_HiEnd(DWORD num, FILE *f)
   BYTESWAP_uint32(num);
   return(fwrite(&num,1,4,f));
 #else
-BYTE b;
-  b = (BYTE)((num >> 8*3) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 0;
-  b = (BYTE)((num >> 8*2) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 1;
-  b = (BYTE)((num >> 8*1) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 2;
-  b = (BYTE)((num >> 8*0) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 3;
+uint8_t b;
+  b = (uint8_t)((num >> 8*3) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 0;
+  b = (uint8_t)((num >> 8*2) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 1;
+  b = (uint8_t)((num >> 8*1) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 2;
+  b = (uint8_t)((num >> 8*0) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 3;
 return 4;
 #endif
 #endif
@@ -305,7 +305,7 @@ return 4;
 #ifndef WrQWORD_HiEnd
 /* Write a quad word to the binary file in a HiEndian Format
  * parameters: FILE  *f :  binary input file
- *             DWORD num : double word to be written */
+ *             uint32_t num : double word to be written */
 int WrQWORD_HiEnd(QWORD_ num, FILE *f)
 {
 #ifdef HI_ENDIAN
@@ -315,15 +315,15 @@ int WrQWORD_HiEnd(QWORD_ num, FILE *f)
   BYTESWAP_uint64(num);
   return(fwrite(&num,1,8,f));
 #else
-BYTE b;
-  b = (BYTE)((num >> 8*7) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 0;    
-  b = (BYTE)((num >> 8*6) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 1;
-  b = (BYTE)((num >> 8*5) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 2;
-  b = (BYTE)((num >> 8*4) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 3;  
-  b = (BYTE)((num >> 8*3) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 4;
-  b = (BYTE)((num >> 8*2) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 5;
-  b = (BYTE)((num >> 8*1) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 6;
-  b = (BYTE)((num >> 8*0) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 7;
+uint8_t b;
+  b = (uint8_t)((num >> 8*7) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 0;    
+  b = (uint8_t)((num >> 8*6) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 1;
+  b = (uint8_t)((num >> 8*5) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 2;
+  b = (uint8_t)((num >> 8*4) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 3;  
+  b = (uint8_t)((num >> 8*3) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 4;
+  b = (uint8_t)((num >> 8*2) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 5;
+  b = (uint8_t)((num >> 8*1) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 6;
+  b = (uint8_t)((num >> 8*0) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 7;
 return 8;
 #endif
 #endif
@@ -334,7 +334,7 @@ return 8;
 #ifndef WrQWORD_LoEnd
 /* Write a quad word to the binary file in a LowEndian Format
  * parameters: FILE  *f :  binary input file
- *             DWORD num : double word to be written */
+ *             uint32_t num : double word to be written */
 int WrQWORD_LoEnd(QWORD_ num, FILE *f)
 {
 #ifdef LO_ENDIAN
@@ -344,15 +344,15 @@ int WrQWORD_LoEnd(QWORD_ num, FILE *f)
   BYTESWAP_uint64(num);
   return(fwrite(&num,1,8,f));
 #else
-BYTE b;
-  b = (BYTE)((num >> 8*0) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 0;
-  b = (BYTE)((num >> 8*1) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 1;
-  b = (BYTE)((num >> 8*2) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 2;
-  b = (BYTE)((num >> 8*3) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 3;  
-  b = (BYTE)((num >> 8*4) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 4;
-  b = (BYTE)((num >> 8*5) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 5;
-  b = (BYTE)((num >> 8*6) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 6;
-  b = (BYTE)((num >> 8*7) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 7;    
+uint8_t b;
+  b = (uint8_t)((num >> 8*0) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 0;
+  b = (uint8_t)((num >> 8*1) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 1;
+  b = (uint8_t)((num >> 8*2) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 2;
+  b = (uint8_t)((num >> 8*3) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 3;  
+  b = (uint8_t)((num >> 8*4) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 4;
+  b = (uint8_t)((num >> 8*5) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 5;
+  b = (uint8_t)((num >> 8*6) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 6;
+  b = (uint8_t)((num >> 8*7) & 0x00FFl); if(!fwrite(&b, 1,1,f)) return 7;    
 return 8;
 #endif
 #endif
@@ -360,28 +360,28 @@ return 8;
 #endif
 
 
-/** Read a WORD from byte stream. */
-WORD fil_sreadU16(const BYTE *in)
+/** Read a uint16_t from byte stream. */
+uint16_t fil_sreadU16(const uint8_t *in)
 {
 #ifdef LO_ENDIAN
- return *(WORD *)in;
+ return *(uint16_t *)in;
 #else
- return (WORD)in[0] +
-       ((WORD)in[1] << 8);
+ return (uint16_t)in[0] +
+       ((uint16_t)in[1] << 8);
 #endif
 }
 
 
-/** Read a DWORD from byte stream. */
-DWORD fil_sreadU32(const BYTE *in)
+/** Read a uint32_t from byte stream. */
+uint32_t fil_sreadU32(const uint8_t *in)
 {
 #ifdef LO_ENDIAN
- return *(DWORD *)in;
+ return *(uint32_t *)in;
 #else
- return (DWORD)in[0] +
-      ((DWORD)in[1] << 8) +
-      ((DWORD)in[2] << 8*2) +
-      ((DWORD)in[3] << 8*3);
+ return (uint32_t)in[0] +
+      ((uint32_t)in[1] << 8) +
+      ((uint32_t)in[2] << 8*2) +
+      ((uint32_t)in[3] << 8*3);
 #endif
 }
 
@@ -401,13 +401,13 @@ int loadstruct(FILE *F,const char *description, ...)
      case 'b':
      case 'B':loaded+=fread(va_arg(ap,char *),1,1,F);
               break;
-     case 'w':loaded+=RdWORD_LoEnd(va_arg(ap,WORD *),F);
+     case 'w':loaded+=RdWORD_LoEnd(va_arg(ap,uint16_t *),F);
      	      break;
-     case 'W':loaded+=RdWORD_HiEnd(va_arg(ap,WORD *),F);
+     case 'W':loaded+=RdWORD_HiEnd(va_arg(ap,uint16_t *),F);
      	      break;
-     case 'd':loaded+=RdDWORD_LoEnd(va_arg(ap,DWORD *),F);
+     case 'd':loaded+=RdDWORD_LoEnd(va_arg(ap,uint32_t *),F);
      	      break;
-     case 'D':loaded+=RdDWORD_HiEnd(va_arg(ap,DWORD *),F);
+     case 'D':loaded+=RdDWORD_HiEnd(va_arg(ap,uint32_t *),F);
      	      break;
      case 'q':loaded+=RdQWORD_LoEnd(va_arg(ap,QWORD_ *),F);
      	      break;
@@ -455,9 +455,9 @@ int savestruct(FILE *F, const char *description, ...)
      case 'B':{const char c = va_arg(ap,char);
 	      writed+=fwrite(&c,1,1,F);}
               break;	
-     case 'w':writed += WrWORD_LoEnd(va_arg(ap,WORD),F);
+     case 'w':writed += WrWORD_LoEnd(va_arg(ap,uint16_t),F);
      	      break;
-     case 'W':writed+=WrWORD_HiEnd(va_arg(ap,WORD),F);
+     case 'W':writed+=WrWORD_HiEnd(va_arg(ap,uint16_t),F);
      	      break;
 #else	//all shorts are internally converted to int
      case 'b':
@@ -469,9 +469,9 @@ int savestruct(FILE *F, const char *description, ...)
      case 'W':writed += WrWORD_HiEnd(va_arg(ap,int),F);
      	      break;
 #endif
-     case 'd':writed += WrDWORD_LoEnd(va_arg(ap,DWORD),F);
+     case 'd':writed += WrDWORD_LoEnd(va_arg(ap,uint32_t),F);
      	      break;
-     case 'D':writed += WrDWORD_HiEnd( va_arg(ap,DWORD),F);
+     case 'D':writed += WrDWORD_HiEnd( va_arg(ap,uint32_t),F);
      	      break;
 
      case 'a':
@@ -487,11 +487,11 @@ int savestruct(FILE *F, const char *description, ...)
      	      break;
      case 'Q':writed+=WrQWORD_HiEnd(va_arg(ap,QWORD_),F);
      	      break;
-     case 'e':{const double e = va_arg(ap,double);
-              writed+=WrQWORD_LoEnd(*(const QWORD_*)&e,F);}
+     case 'e':{const QWORD_ e = va_arg(ap,QWORD_);
+              writed+=WrQWORD_LoEnd(e,F);}
      	      break;
-     case 'E':{const double e = va_arg(ap,double);
-              writed+=WrQWORD_HiEnd(*(const QWORD_*)&e,F);}
+     case 'E':{const QWORD_ e = va_arg(ap,QWORD_);
+              writed+=WrQWORD_HiEnd(e,F);}
      	      break;
 
      default:printf("Error: Unknown character %c !", *description);
