@@ -333,7 +333,7 @@ unsigned TablePosStart;
     "                break;  // standard ASCII character\n"
     "     case 852:\n"
     "     case 1250: unicode = (*Convert2Target)[wchar_code];\n"
-    "                if(unicode>=128) return ExpandPlainChar(unicode);\n"
+    "                if(unicode>=128 && unicode<=255) return ExpandPlainChar((uint8_t)unicode);\n"
     "                break;  // standard ASCII character\n"
     "     }\n"
     "   }\n"
