@@ -636,7 +636,7 @@ bool FirstCipher = false;
        {
        if((isspace(8)||str[8]=='{') && (LastC=='\\' || isspace(LastC)))
 	 {
-	 c = str[8];	   
+	 c = str[8];
 	 str = copy(str, 8, length(str)-8);
 	 arg += "overline";
 	 if(c=='{')
@@ -646,7 +646,7 @@ bool FirstCipher = false;
 	   i++;
            }
 	 continue;			// continue outer loop
-	 }         
+	 }
        }
 
      str=copy(str,1,length(str)-1);
@@ -660,7 +660,7 @@ bool FirstCipher = false;
 			 str = c+str;	// return curly brace back
 			 break;
 			 }
-	      i++;	  
+	      i++;
 	      }
 	 if(c == '}')
 	      {
@@ -887,8 +887,8 @@ bool RemoveLastArg(string & str, string & arg)
 //#ifdef DEBUG
 //  fprintf(cq->log,"\n#RemoveLastArg(%s,%s) ", chk(str()), chk(arg())); fflush(cq->log);
 //#endif
-int i,j;
-char c,LastC;
+int i, j;
+char c, LastC;
 
   LastC=0;
   arg.erase();
@@ -897,7 +897,7 @@ char c,LastC;
       str = copy(str,0,length(str)-1);
       }
 
-  i=0;			//Tady je chyba !!!!!!!!!!!!!!!!!!!!!
+  i = 0;			//Tady je chyba !!!!!!!!!!!!!!!!!!!!!
   while(!str.isEmpty()) // && (str[length(str) - 1] != ' ' || i != 0))
       {
       c = str[length(str) - 1];
@@ -905,12 +905,12 @@ char c,LastC;
 	 {
 	 if(length(arg)>0)
 		{
-		if (c == '^' || c == '_' || c == '{' || c == '&' || c == '#' || c == ',' || c == ';' ||
+		if(c == '^' || c == '_' || c == '{' || c == '&' || c == '#' || c == ',' || c == ';' ||
 		    c == '$' || c == '@' || c == '%' || c == '*'  || isspace(c) || c == '+' || c == '-' || c == '=' ||
 		    c == ']' || c == '[' || c == '(' || c == ')' || c == '/')
 				  break;
-		if ( (isalpha(LastC) || LastC==0) && !isalpha(LastC)) break;
-		if ( c == '\\')
+		if((isalpha(LastC) || LastC==0) && !isalpha(LastC)) break;
+		if(c == '\\')
 			{
 			str=copy(str,0,length(str)-1);
 			arg=c+arg;
@@ -921,21 +921,21 @@ char c,LastC;
 
       str=copy(str,0,length(str)-1);
 
-      if (c == '}')
+      if(c == '}')
 	  {
 	  i++;
-	  if (i == 1)
+	  if(i == 1)
 		{
 		if(arg.isEmpty()) continue;
 		str+='}';	// fix the situation    "{...}arg"
-		i--;
+		//i--;		//'i' is not needed because of break.
 		break;
 		}
 	  }
-      if (c == '{')
+      if(c == '{')
 	  {
 	  i--;
-	  if (i == 0) break;
+	  if(i == 0) break;
 	  }
 
       if(c==')' || c==']' || str[0]=='|')
@@ -951,7 +951,7 @@ char c,LastC;
 		continue;
 		}
 	  }
-      if( (c=='(' || c=='[' || str[0]=='|') && i>0)
+      if((c=='(' || c=='[' || str[0]=='|') && i>0)
 	  {
 	  j=length(str) - 2;
 	  if(isspace(str[j])) j--;
@@ -1381,35 +1381,36 @@ bool MathArray = false;
 void FixSubSup(string & StrBeg, string & StrEnd)
 {
 string arg;
-char ch,ch2;
+char ch2;
 
-ch2=0;
+ch2 = 0;
 while(length(StrEnd)>0)
-	{
-	ch=StrEnd[0];
-	switch(ch)
-	  {
-	  case '^':
-	  case '_':StrBeg+=ch;
-		   StrEnd=copy(StrEnd,1,length(StrEnd)-1);
-		   Remove1stArg(StrEnd, arg);
-		   if(StrEnd[0]==ch || (ch2 && (StrEnd[0]=='_' || StrEnd[0]=='^')) )
-			{
-			StrBeg+="{{";
-			StrBeg+=arg;
-			StrBeg+='}';
-			RemoveAdvanced1stArg(StrEnd, arg);
-			StrEnd=arg+'}'+StrEnd;
-			ch2=0;
-			}
-		   else {
-			StrBeg+='{'+arg+'}';
-			ch2=ch;
-			}
-		   break;
-	  default:StrBeg+=StrEnd[0];
-		  StrEnd=copy(StrEnd,1,length(StrEnd)-1);
+{
+  const char ch = StrEnd[0];
+  switch(ch)
+  {
+	case '^':
+	case '_':StrBeg+=ch;
+		 StrEnd=copy(StrEnd,1,length(StrEnd)-1);
+		 Remove1stArg(StrEnd, arg);
+		 if(StrEnd[0]==ch || (ch2 && (StrEnd[0]=='_' || StrEnd[0]=='^')) )
+		{
+		  StrBeg+="{{";
+		  StrBeg+=arg;
+		  StrBeg+='}';
+		  RemoveAdvanced1stArg(StrEnd, arg);
+		  StrEnd=arg+'}'+StrEnd;
 		  ch2=0;
+		}
+		 else
+		{
+		  StrBeg+='{'+arg+'}';
+		  ch2 = ch;
+		}
+		break;
+	default:StrBeg+=StrEnd[0];
+		StrEnd=copy(StrEnd,1,length(StrEnd)-1);
+		ch2 = 0;
 	  }
 	}
 }
