@@ -12,7 +12,8 @@
 
 /** This class is a container for loader modules. */
 TImageFileHandler *TImageFileHandler::First=NULL;
-TImageFileHandler::TImageFileHandler(const char *NewExtension, TLoadPicture LoadPicture_XXX, TSavePicture SavePicture_XXX, const char *NewDescription)
+TImageFileHandler::TImageFileHandler(const char *NewExtension, TLoadPicture LoadPicture_XXX, TSavePicture SavePicture_XXX, const char *NewDescription, const uint32_t NewFlags):
+	Flags(NewFlags)
 {
  Extension=NewExtension;
  Description=NewDescription;
@@ -48,15 +49,15 @@ const char *ReadExt(const char *FileName)
 const char *c;
 
  if(FileName==NULL) return NULL;
- c = FileName+strlen(FileName);
+ const size_t LastPos = strlen(FileName);
+ c = FileName + LastPos;
  while (c!=FileName)
       {
       if(*c=='.') return(++c);
       if((*c=='/') || (*c=='\\') || (*c==':')) break;	//file has No Ext
       c--;
       }
-
-return(FileName+strlen(FileName));	// 0
+return(FileName+LastPos);	// 0
 }
 
 
@@ -109,12 +110,12 @@ return(Img);
 
 
 /** Main procedure for saving images. This should be called preferably. */
-int SavePicture(const char *Name,const Image &Img)
+int SavePicture(const char *Name, const Image &Img)
 {
 TImageFileHandler *SavePicture_XXX;
 const char *ext,*ext2;
 
-  ext=ReadExt(Name);
+  ext = ReadExt(Name);
   for(SavePicture_XXX=TImageFileHandler::first();SavePicture_XXX!=NULL;SavePicture_XXX=SavePicture_XXX->next())
     {
     if(SavePicture_XXX->SavePicture!=NULL)
