@@ -137,7 +137,7 @@ void RGB32_BGR24(unsigned char *OutData, const unsigned char *InData, unsigned P
 }
 
 
-void BGR_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
+void BGR_Gray24precise(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
 {
   while(PixelCount-->0)
   {
@@ -148,12 +148,23 @@ void BGR_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned Pi
 }
 
 
+void BGR32_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
+{
+  while(PixelCount-->0)
+  {
+    OutData[2]=OutData[1]=OutData[0] = (InData[0]*4731 + InData[1]*46871 + InData[2]*13932)/65536;
+    InData+=4;
+    OutData+=3;
+  }
+}
+
+
 void RGB32_Gray(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
 {
   while(PixelCount-->0)
   {
-    *(OutData++) = (*(InData++) + *(InData++) + *(InData++)) / 3;
-    InData++;
+    *(OutData++) = (*InData + InData[1] + InData[2]) / 3;
+    InData += 4;
   }
 }
 
@@ -162,7 +173,19 @@ void RGB_Gray(unsigned char *OutData, const unsigned char *InData, unsigned Pixe
 {
   while(PixelCount-->0)
   {
-    *(OutData++) = (*(InData++) + *(InData++) + *(InData++)) / 3;
+    *OutData++ = (*InData+InData[1]+InData[2]) / 3;
+    InData+=3;
+  }
+}
+
+
+void RGB_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
+{
+  while(PixelCount-->0)
+  {    
+    *OutData = OutData[1] = OutData[2] = (*InData+InData[1]+InData[2]) / 3;
+    OutData+=3;
+    InData+=3;
   }
 }
 
