@@ -28,7 +28,7 @@ void RGBA32_BGRiA32(char *Data, int PixelCount);
 void RGBA64_BGRiA64(char *Data, int PixelCount);
 void RGB_Gray(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount);
 void RGB_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount);
-void BGR_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount);
+void BGR_Gray24precise(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount);
 void BGR32_Gray24(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount);
 void RGB32_Gray(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount);
 
