@@ -506,10 +506,11 @@ TImageFileHandler TIFF_H(".TIFF",
    NULL,
  #endif
  #if SupportJPG>=3
-   SavePictureJPG);
+   SavePictureJPG,
  #else
-   NULL);
+   NULL,
  #endif
+   NULL, FILE_FORMAT_CAP_EXIF);
 
  TImageFileHandler JPEG_HANDLER(".JPEG",
  #if SupportJPG>=4 || SupportJPG==2
@@ -518,10 +519,11 @@ TImageFileHandler TIFF_H(".TIFF",
 	NULL,
  #endif
  #if SupportJPG>=3
-	SavePictureJPG);
+	SavePictureJPG,
  #else
-	NULL);
+	NULL,
  #endif
+	NULL, FILE_FORMAT_CAP_EXIF);
 #endif
 
 
@@ -533,10 +535,11 @@ TImageFileHandler TIFF_H(".TIFF",
    NULL,
  #endif
  #if SupportPNG>=3
-   SavePicturePNG);
+   SavePicturePNG,
  #else
-   NULL);
+   NULL,
  #endif
+   NULL, FILE_FORMAT_CAP_EXIF);
 #endif
 
 
@@ -568,4 +571,3 @@ TImageFileHandler TIFF_H(".TIFF",
 	NULL);
 #endif
 #endif
-
