@@ -1,9 +1,9 @@
 /******************************************************************************
- * program:     rasimg library 0.25                                           *
+ * program:     rasimg library 0.26                                           *
  * function:    Miscellaneous utilities for manipulation with images.         *
- * modul:       rasterut.cc                                                   *
+ * modul:       imgut.cc                                                      *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 1998-2023 Jaroslav Fojtik                                   *
+ * Copyright: (c) 1998-2024 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #include<stdio.h>
 #include<string.h>
@@ -25,6 +25,38 @@
 
 /* ------------ Properties ---------------*/
 
+PropertyItem::PropertyItem(void)
+{
+  Data=NULL;
+  DataSize=0;
+  UsageCount=0;
+}
+
+
+PropertyItem::PropertyItem(const char *NewName): Name(NewName)
+{
+  Data=NULL;
+  DataSize=0;
+  UsageCount=0;
+}
+
+
+PropertyItem::PropertyItem(const char *NewName, unsigned IniSize): Name(NewName)
+{
+  DataSize = 0;
+  if(IniSize>0)
+  {
+    Data = malloc(IniSize);
+    if(Data) DataSize=IniSize;
+  }
+  else
+  {
+    Data=NULL;
+  }
+  UsageCount=0;
+}
+
+
 PropertyItem::~PropertyItem()
 {
   if(Data)
@@ -92,6 +124,26 @@ int i;
 }
 
 
+/// Find property with a given name.
+/// @param[in]	FindName	Property to search.
+/// @param[in,out] PropIDX	Starting search index.
+const PropertyItem *PropertyList::Find(const char *FindName, unsigned &PropIDX) const
+{
+  if(pProperties==NULL) return NULL;
+
+  while(PropIDX<PropCount)
+  {    
+    const PropertyItem *pProp = pProperties[PropIDX];
+    PropIDX++;
+    if(pProp->Data!=NULL && pProp->DataSize>0)
+    {
+      if(pProp->Name==FindName) return pProp;
+    }
+  }
+return NULL;
+}
+
+
 /* ---------- Global class Image --------- */
 void Image::Create(unsigned SizeX, unsigned SizeY, int Planes)
 {
@@ -185,7 +237,7 @@ CopyImg:if((PImg->Raster=CurrImg->Raster)!=NULL)
                 CurrImg->VecImage->UsageCount++;
         if(!CurrImg->Properties.isEmpty())
 	  {
-          for(int i=0; i<CurrImg->Properties.PropCount; i++)
+          for(unsigned i=0; i<CurrImg->Properties.PropCount; i++)
             PImg->Properties.AddProp(CurrImg->Properties.pProperties[i]);
           }
 	CurrImg = CurrImg->Next;
@@ -628,3 +680,186 @@ Finish:
 
 return CurrentColors;
 }
+
+
+//////////////////////////////////////////////////////////
+
+
+/// Looks throuh whole image list chain for EXIF block.
+bool HasExif(const Image *pI)
+{
+  while(pI != NULL)
+  {
+    unsigned i = 0;
+    if(pI->Properties.Find("Exif",i) != NULL) return true;
+    pI = pI->Next;
+  }
+return false;
+}
+
+#define TIFFTAG_ORIENTATION 274            /* +image orientation */
+
+static uint32_t fLD_UINT32_LO(const unsigned char *Mem)
+{
+#ifdef WORDS_BIGENDIAN
+  return (uint32_t)Mem[0] | ((uint32_t)Mem[1] << 8) | ((uint32_t)Mem[2] << 16) | ((uint32_t)Mem[3] << 24);
+#else
+  return *(uint32_t*)Mem;
+#endif
+}
+
+static uint32_t fLD_UINT32_HI(const unsigned char *Mem)
+{
+  return ((uint32_t)Mem[0]<<24) | ((uint32_t)Mem[1] << 16) | ((uint32_t)Mem[2] << 8) | ((uint32_t)Mem[3]);
+}
+
+static uint16_t fLD_UINT16_LO(const unsigned char *Mem)
+{
+#ifdef WORDS_BIGENDIAN
+  return (uint16_t)Mem[0] | ((uint16_t)Mem[1] << 8);
+#else
+  return *(uint16_t*)Mem;
+#endif
+}
+
+static uint16_t fLD_UINT16_HI(const unsigned char *Mem)
+{
+  return ((uint16_t)Mem[0] << 8) | ((uint16_t)Mem[1]);
+}
+
+
+/// https://www.media.mit.edu/pia/Research/deepview/exif.html
+class ExifParser
+{
+public:
+	ExifParser(const unsigned char *pProfile, const uint32_t new_profile_length);
+
+	const unsigned char *profile_data;
+        const unsigned char *profile_end;
+	
+        bool isValid(void) const {return LD_UINT32!=NULL;}
+        const unsigned char *FindExifField(uint16_t ReqTag, const unsigned char *IFD_data=NULL) const;
+
+	uint32_t(*LD_UINT32)(const unsigned char *Mem);
+	uint16_t(*LD_UINT16)(const unsigned char *Mem);
+};
+
+
+ExifParser::ExifParser(const unsigned char *pProfile, const uint32_t new_profile_length): profile_data(pProfile), profile_end(pProfile+new_profile_length)
+{
+unsigned char ByteOrder = 0;
+
+  if(new_profile_length>=12+8 && pProfile!=NULL)
+  {
+    ByteOrder = *profile_data;
+  }
+
+  switch(ByteOrder)
+  {
+    case 'M': LD_UINT32 = fLD_UINT32_HI;
+              LD_UINT16 = fLD_UINT16_HI;
+              break;
+    case 'I': LD_UINT32 = fLD_UINT32_LO;
+              LD_UINT16 = fLD_UINT16_LO;
+              break;
+    default:  LD_UINT32 = NULL;
+              LD_UINT16 = NULL;
+              break;
+  }
+}
+
+
+const unsigned char *ExifParser::FindExifField(uint16_t ReqTag, const unsigned char *IFD_data) const
+{
+uint16_t EntryNum;
+uint16_t Tag;
+uint32_t Value;
+
+  if(!isValid()) return NULL;
+
+  if(IFD_data==NULL)
+  {
+    if(profile_end-profile_data < 8) return NULL;
+    Value = LD_UINT32(profile_data+4);
+    IFD_data = profile_data + LD_UINT32(profile_data+4);
+  }
+
+  do
+  {
+    if(profile_end-IFD_data < 2) break;
+    EntryNum = LD_UINT16(IFD_data);
+    IFD_data+=2;
+    if(profile_end-IFD_data < EntryNum*12) break;
+
+    while(EntryNum>0)
+    {
+      Tag = (LD_UINT16)(IFD_data);
+
+      if(Tag==ReqTag) return IFD_data;
+
+      //Field = (LD_UINT16)(IFD_data+2);
+      //Long2 = (LD_UINT32)(IFD_data+4);
+      //Value = (LD_UINT32)(IFD_data+8);
+
+      IFD_data += 12;
+      EntryNum--;
+    }
+
+    if(profile_end-IFD_data < 4) break;
+    Value = LD_UINT32(IFD_data);
+    IFD_data = profile_data + Value;
+  } while(Value>8);
+
+  return NULL;
+}
+
+
+void AutoOrient(Image *pI)
+{
+  while(pI != NULL)
+  {
+    unsigned i = 0;
+    const PropertyItem *PI = pI->Properties.Find("Exif",i);
+    if(PI==NULL) break;
+
+    ExifParser EP((const unsigned char *)PI->Data, PI->DataSize);
+    const unsigned char *pIFD = EP.FindExifField(TIFFTAG_ORIENTATION);
+    if(pIFD != NULL)
+    {
+      uint16_t Field;
+      uint32_t Long2, Value;
+
+      Field = (EP.LD_UINT16)(pIFD+2);
+      Long2 = (EP.LD_UINT32)(pIFD+4);
+      Value = (EP.LD_UINT32)(pIFD+8);
+
+      if(Value>=5 && Value<=8)
+      {
+        Raster2DAbstract *rFlip = Flip1D2D(pI->Raster);
+        if(rFlip) pI->AttachRaster(rFlip);
+      }
+
+      switch(Value)
+      {
+	case 5:				// The 0th row represents the visual left-hand side of the image, and the 0th column represents the visual top.
+        default:
+        case 0: 
+        case 1: break;			// The 0th row represents the visual top of the image, and the 0th column represents the visual left-hand side.
+
+	case 6:				// The 0th row represents the visual right-hand side of the image, and the 0th column represents the visual top.
+	case 2: Flip1D(pI->Raster);	// The 0th row represents the visual top of the image, and the 0th column represents the visual right-hand side.
+		break;
+        case 7:				// The 0th row represents the visual right-hand side of the image, and the 0th column represents the visual bottom.
+	case 3:	Flip2D(pI->Raster);	// The 0th row represents the visual bottom of the image, and the 0th column represents the visual right-hand side.
+		Flip1D(pI->Raster);
+		break;
+	case 8:				// The 0th row represents the visual left-hand side of the image, and the 0th column represents the visual bottom. 
+	case 4: Flip2D(pI->Raster);	// The 0th row represents the visual bottom of the image, and the 0th column represents the visual left-hand side.
+		break;
+      }
+    }
+    pI = pI->Next;
+  }
+}
+
+
