@@ -7,7 +7,7 @@
 #include <stdio.h>
 
 #include <stdlib.h>
-#if defined(_MSC_VER) || defined(__CYGWIN32__) || defined(__APPLE__) || defined(__MINGW32__)
+#if defined(_MSC_VER) || defined(__CYGWIN32__) || defined(__APPLE__) || defined(__MINGW32__) || defined(__MINGW64__)
  #define MAXLONG     0x7FFFFFFF
 #else
  #include <values.h>
