@@ -43,7 +43,7 @@ struct my_error_mgr {
 };
 
 typedef struct my_error_mgr * my_error_ptr;
-int JPG_quality = 75;
+#define DEFAULT_JPG_QUALITY	75
 
 
 /* Here's the routine that will replace the standard error_exit method: */
@@ -91,7 +91,7 @@ static inline int GetProfileLength(j_decompress_ptr jpeg_info)
 
 static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
 {
-  size_t header_length=0, length;
+  size_t length;
   register size_t i;
   string profile_name;
 //  unsigned char *profile;
@@ -145,10 +145,12 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
 
   length -= 6;
 
-  PropertyItem *PropExif = new PropertyItem;
-  PropExif->Data = (unsigned char *)malloc(length);
-  if(PropExif->Data==NULL) return TRUE;
-  PropExif->DataSize = length;
+  PropertyItem *PropExif = new PropertyItem(ExifPreffix,length);
+  if(PropExif->Data==NULL)
+  {
+    delete PropExif;
+    return TRUE;
+  }
 
   for(i=0 ; i < length ; i++)
   {
@@ -160,7 +162,6 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
     }
     ((char*)PropExif->Data)[i] = c;
   }
-  PropExif->Name = ExifPreffix;
   Img->AttachProperty(PropExif);
 
 /*
@@ -168,7 +169,7 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
            (memcmp(profile, xmp_std_header, strlen(xmp_std_header)+1) == 0))
   {
 	// XMP is required to fit in one 64KB chunk.  Strip off its JPEG namespace header.
-     header_length = strlen(xmp_std_header)+1;
+     length = strlen(xmp_std_header)+1;
      //FormatString((char *) profile_name,"XMP");
   }
 */
@@ -218,7 +219,7 @@ unsigned current_line = 0;
    *   (b) we passed TRUE to reject a tables-only JPEG file as an error.
    * See libjpeg.doc for more info. */
 
-   Raster2DAbstract *Raster = CreateRaster2D(cinfo.image_width,cinfo.image_height,24);
+   Raster2DAbstract *Raster = CreateRaster2DRGB(cinfo.image_width,cinfo.image_height,8);
    if(Raster==NULL) return NULL;
 
 	/* Step 5: Start decompressor */
@@ -325,7 +326,7 @@ int i;
    *   (b) we passed TRUE to reject a tables-only JPEG file as an error.
    * See libjpeg.doc for more info. */
 
-   Raster2DAbstract *Raster = CreateRaster2D(cinfo.image_width,cinfo.image_height,24);
+   Raster2DAbstract *Raster = CreateRaster2DRGB(cinfo.image_width,cinfo.image_height,8);
    if(Raster==NULL) goto ENDPROC;
 
   /* Step 4: set parameters for decompression */
@@ -404,8 +405,11 @@ ENDPROC:
 
 
 #if SupportJPG>=3
-int SavePictureJPG(const char *Name,const Image &Img)
+int SavePictureJPG(const char *Name, const Image &Img)
 {
+const PropertyItem *Prop;
+unsigned i;
+
   /* This struct contains the JPEG compression parameters and pointers to
    * working space (which is allocated as needed by the JPEG library).
    * It is possible to have several such structures, representing multiple
@@ -464,7 +468,13 @@ int row_stride;		 /* physical row width in image buffer */
   jpeg_set_defaults(&cinfo);
   /* Now you can set any non-default parameters you wish to.
    * Here we just illustrate the use of quality (quantization table) scaling:   */
-  jpeg_set_quality(&cinfo, JPG_quality, TRUE /* limit to baseline-JPEG values */);
+  i = 0;
+  Prop = Img.Properties.Find("JPG_QUALITY",i);
+  if(Prop && Prop->DataSize>=sizeof(int))
+    i = *(int*)Prop->Data;
+  else
+    i = DEFAULT_JPG_QUALITY;
+  jpeg_set_quality(&cinfo, i, TRUE /* limit to baseline-JPEG values */);
 
   /* Step 4: Start compressor */
 
@@ -475,22 +485,19 @@ int row_stride;		 /* physical row width in image buffer */
 
   if(!Img.Properties.isEmpty())
   {
-    for(int i=0; i<Img.Properties.PropCount; i++)
+    i = 0;
+    while((Prop=Img.Properties.Find(ExifPreffix,i)) != NULL)
     {
-      PropertyItem *Prop = Img.Properties.pProperties[i];
-      if(Prop!=NULL && Prop->Data!=NULL && Prop->DataSize>0 && Prop->Name=="Exif")
-      {
-        int j;
+      int j;
 		// First chunk is scattered into 2 pieces.
-        jpeg_write_m_header(&cinfo, JPEG_APP0+1, (int)MIN(Prop->DataSize+6,65533L));
-        for(j=0; j<6; j++) jpeg_write_m_byte (&cinfo, ExifPreffix[j]);
-        for(j=0; j<(int)MIN(Prop->DataSize,65533L-6); j++)
+      jpeg_write_m_header(&cinfo, JPEG_APP0+1, (int)MIN(Prop->DataSize+6,65533L));
+      for(j=0; j<6; j++) jpeg_write_m_byte (&cinfo, ExifPreffix[j]);
+      for(j=0; j<(int)MIN(Prop->DataSize,65533L-6); j++)
           jpeg_write_m_byte (&cinfo, ((unsigned char*)Prop->Data)[j]);
-        while(j<Prop->DataSize)
-        {
-          jpeg_write_marker(&cinfo, JPEG_APP0+1, (unsigned char*)Prop->Data+j, (int)MIN(Prop->DataSize-j,65533L));
-          j += 65533L;
-        }
+      while(j<Prop->DataSize)
+      {
+        jpeg_write_marker(&cinfo, JPEG_APP0+1, (unsigned char*)Prop->Data+j, (int)MIN(Prop->DataSize-j,65533L));
+        j += 65533L;
       }
     }
   }
@@ -520,8 +527,8 @@ int row_stride;		 /* physical row width in image buffer */
              RGBQuad RGB;
              uint8_t *ptrLine=(uint8_t *)ptrLineX;
              for(unsigned X=0;X<RasLine->GetSize1D();X++)
-	       {
-	       Img.Palette->Get(RasLine->GetValue1D(X),&RGB);
+               {
+               Img.Palette->Get(RasLine->GetValue1D(X),&RGB);
                *ptrLine++=RGB.R;
                *ptrLine++=RGB.G;
                *ptrLine++=RGB.B;
