@@ -1,9 +1,9 @@
 /******************************************************************************
- * Unit:    raster            release 0.25                                    *
+ * Unit:    raster            release 0.26                                    *
  * Prototype declaration of separate classes. Normally this is not needed     *
  * to be included.                                                            *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 1998-2023 Jaroslav Fojtik                                   *
+ * Copyright: (c) 1998-2024 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #ifndef _RAS_PROT_H_
 #define _RAS_PROT_H_
@@ -268,9 +268,9 @@ class Raster1D_16Bit565: virtual public Raster1D_16Bit, virtual public Raster1DA
 public: Raster1D_16Bit565(int InitSize1D): Raster1D_16Bit(InitSize1D) {}
         Raster1D_16Bit565() {}
 
-	virtual unsigned R(unsigned x) const;
-	virtual unsigned G(unsigned x) const;
-	virtual unsigned B(unsigned x) const;
+	virtual uint32_t R(unsigned x) const;
+	virtual uint32_t G(unsigned x) const;
+	virtual uint32_t B(unsigned x) const;
 
 	virtual uint32_t GetValue1D(unsigned x) const;
 	virtual void SetValue1D(unsigned x, uint32_t NewValue);
