@@ -1,10 +1,10 @@
 /*************************************************************
- * Unit:    raster            release 0.25                   *
+ * Unit:    raster            release 0.27                   *
  * Purpose: General manipulation n dimensional matrices      *
  *          n = 1, 2 and 3.			             *
  * Modul:   raster.cc                                        *
  * Licency: GPL or LGPL                                      *
- * Copyright: (c) 1998-2023 Jaroslav Fojtik                  *
+ * Copyright: (c) 1998-2024 Jaroslav Fojtik                  *
  *************************************************************/
 #include<stdio.h>
 #include<string.h>
@@ -2103,11 +2103,18 @@ void Raster1D_8BitRGBA::SetValue1D(unsigned x, uint32_t NewValue)
 
 void Raster1D_8BitRGBA::Get(unsigned x, RGBQuad *RGB) const
 {
-uint32_t d = ((uint32_t *)Data1D)[x];
+const uint32_t d = ((uint32_t *)Data1D)[x];
+#ifdef HI_ENDIAN
+  RGB->O = d & 0xFF;
+  RGB->B = (d>>8) & 0xFF;
+  RGB->G = (d>>16) & 0xFF;
+  RGB->R = (d>>24) & 0xFF;
+#else
   RGB->R = d & 0xFF;
   RGB->G = (d>>8) & 0xFF;
   RGB->B = (d>>16) & 0xFF;
   RGB->O = (d>>24) & 0xFF;
+#endif
 }
 
 
@@ -2119,9 +2126,15 @@ uint8_t *BBuffer24Bit = (uint8_t *)Buffer24Bit;
   for(unsigned x=0; x<Size1D; x++)
   {
     const uint32_t d = ((const uint32_t *)Data1D)[x];
+#ifdef HI_ENDIAN
+    *BBuffer24Bit++ = (d>>24) & 0xFF;
+    *BBuffer24Bit++ = (d>>16) & 0xFF;
+    *BBuffer24Bit++ = (d>>8) & 0xFF;
+#else
     *BBuffer24Bit++ = d & 0xFF;
     *BBuffer24Bit++ = (d>>8) & 0xFF;
     *BBuffer24Bit++ = (d>>16) & 0xFF;
+#endif
   }
 }
 
@@ -2131,7 +2144,11 @@ uint8_t *BBuffer24Bit = (uint8_t *)Buffer24Bit;
 uint32_t Raster1D_8BitRGBA::PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const
 {
   if(x>=Size1D) return 0;
-  return ((const uint32_t*)RAW_Data1D)[x];
+  return
+#ifdef HI_ENDIAN
+	__builtin_bswap32
+#endif
+		(((const uint32_t*)RAW_Data1D)[x]);
 }
 
 void Raster1D_8BitRGBA::PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const
@@ -2396,6 +2413,14 @@ void Raster2DAbstract::Get(unsigned Offset1D, unsigned Offset2D, RGBQuad *RGB)
 }
 
 
+void Raster2DAbstract::Set(unsigned Offset1D, unsigned Offset2D, const RGBQuad *RGB)
+{
+  if(Data2D==NULL || Offset2D>=Size2D) return;
+  Data1D = Data2D[Offset2D];
+  ((Raster1DAbstract*)this)->Set(Offset1D,RGB);		//Raster1DAbstract::Get() forces only one method not using VMT.
+}
+
+
 void Raster2DAbstract::Set(unsigned Offset2D, const Raster1DAbstract &R1)
 {
   if(Data2D==NULL || Offset2D>=Size2D) return;  
