@@ -1,9 +1,9 @@
 /******************************************************************************
- * program:     rasimg library 0.25                                           *
+ * program:     rasimg library 0.26                                           *
  * function:    Miscellaneous utilities for manipulation with images.         *
  * modul:       rasterut.cc                                                   *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 1998-2023 Jaroslav Fojtik                                   *
+ * Copyright: (c) 1998-2024 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #include<stdio.h>
 #include<string.h>
@@ -21,6 +21,7 @@
 #endif
 
 
+/// Set pixel for 1bpp 1D image data.
 void SetValue2(uint8_t *b, unsigned x, uint8_t NewValue)
 {
 uint8_t v;
@@ -38,6 +39,7 @@ uint8_t v;
 }
 
 
+/// Get pixel for 1bpp 1D image data.
 uint8_t GetValue2(const uint8_t *b, unsigned x)
 {
  if(b==NULL) return 0;
@@ -71,9 +73,8 @@ void Flip2(uint8_t *b, unsigned len)
 
 //------------------------------------------------------------
 
-/* ---------------------------- */
-
 
+/** This procedure provides flipping of the 1D vector. */
 void Flip1D(Raster1DAbstract *r1D)
 {
   if(r1D==NULL) return;
@@ -361,3 +362,78 @@ void Flip3D(Raster3DAbstract *r3D)
 }
 
 #endif
+
+
+Raster2DAbstract *Flip1D2D(Raster2DAbstract *r2D)
+{
+Raster2DAbstract *rFlip;
+  if(r2D->Data2D==NULL) return NULL;
+
+  int p = r2D->GetPlanes();
+  switch(r2D->Channels())
+  {
+    case 1: rFlip = CreateRaster2D(r2D->Size2D, r2D->Size1D, p);
+	    break;
+    case 3: rFlip = CreateRaster2DRGB(r2D->Size2D, r2D->Size1D, p/3);
+	    break;
+    case 4: rFlip = CreateRaster2DRGB(r2D->Size2D, r2D->Size1D, p/4);
+	    break;
+    default:return NULL;
+  }
+  if(rFlip==NULL) return NULL;
+  if(rFlip->Data2D==NULL)
+  {
+    delete rFlip;
+    return NULL;
+  }
+
+  for(unsigned y=0; y<r2D->Size2D; y++)
+  {
+    switch(p)
+    {
+/*
+      case 1:  Flip1((uint8_t*)r2D->GetRow(y), Size1D);
+	       break;
+      case 2:  Flip2((uint8_t*)r2D->GetRow(y), Size1D);
+	       break;
+      case 4:  Flip4((uint8_t*)r2D->GetRow(y), Size1D);
+	       break;
+      case 8:  Flip8((uint8_t*)r2D->GetRow(y), Size1D);
+	       break;
+      case 16: Flip16((uint16_t*)r2D->GetRow(y), Size1D);
+	       break;
+      case 24: Flip24((uint8_t*)r2D->GetRow(y), Size1D);
+	       break;
+      case 32: Flip32((uint32_t*)r2D->GetRow(y), Size1D);
+	       break;
+#if defined(uint64_t) || defined(uint64_t_defined)
+      case 64: Flip64((uint64_t*)r2D->GetRow(y), Size1D);
+	       break;
+#endif
+*/
+      default: if(r2D->Channels()==1)
+               {
+                 const Raster1DAbstract *r1D = r2D->GetRowRaster(y);
+                 unsigned x = r2D->Size1D;
+	         while(x-- > 0)
+		 {
+		   rFlip->SetValue2D(y,x, r1D->GetValue1D(x));
+		 }
+                 break;
+               }
+               else
+               {
+                 unsigned x = r2D->Size1D;
+                 RGBQuad RGB;
+                 const Raster1DAbstract *r1D = r2D->GetRowRaster(y);
+	         while(x-- > 0)
+		 {                  
+                   r1D->Get(x,&RGB);
+                   rFlip->Set(y,x,&RGB);
+                 }
+               }
+    }
+  }
+
+return rFlip;
+}
