@@ -2082,12 +2082,12 @@ float LastLineSz = 0;
 #ifdef _DEBUG
 void TextContainer::Dump2File(FILE *F) const
 {
-  fputs("TextContainer{",F);  
+  fprintf(F,"TextContainer{[%.2f;%.2f]", PosX, PosY);
   for(int i=0; i<TextObjects; i++)
     {
       if(Text[i]!=NULL)
       {
-      fprintf(F,"FontSz=%f;", Text[i]->size);
+      fprintf(F,"FontSz=%.3f;", Text[i]->size);
       fprintf(F,"%s\"%s\"", (i==0)?"":",", Text[i]->contents());
       }
     }
@@ -2201,13 +2201,13 @@ static void CheckAccent(uint32_t & Feature, const char *PS_text)
   if(StrStr(PS_text,"ACCENTSHOW")!=NULL)  Feature |= EPS_ACCENTSHOW;
 }
 
+
 void TextContainer::FeaturesEPS(uint32_t & Feature) const
 {
   CheckAccent(Feature, Export2EPS()());
 }
 
 
-
 /////////////////////////////////////////////////////////////
 
 #include "typedfs.h"
