@@ -189,7 +189,6 @@ void TconvertedPass1_WP6::CrackResource(int ResourceNo)
 {
   FILE *txt;
   long pos;
-  uint32_t i;
   static char ss[13] = "00_RHack.txt";
   unsigned char c;
   Resource Res;
@@ -215,7 +214,7 @@ void TconvertedPass1_WP6::CrackResource(int ResourceNo)
   if(!c) {
 	 fseek(wpd, Res.ResourceFilePos, 0);
 
-	 for (i=0; i<Res.PacketSize; i++)
+	 for(uint32_t i=0; i<Res.PacketSize; i++)
 		{
 		c = fgetc(wpd);
 		fprintf(txt," %4lu: %u",(long unsigned)i,(unsigned)c);
@@ -227,7 +226,7 @@ void TconvertedPass1_WP6::CrackResource(int ResourceNo)
 
   fclose(txt);
   txt = NULL;
-  ss[1]++;   /**/
+  ss[1]++;
 
   fseek(wpd, pos, 0);
 }
@@ -662,7 +661,7 @@ void TconvertedPass1_WP6::Box6(void)
 				// [hoffset] <left col> <right col>
                                 // <vpos flags> [voffset] <width flags>
 			  fseek(wpd, 8L, SEEK_CUR);
-			  Rd_word(wpd, &wpu); Box.Width=wpu/47.0;	// width [mm]
+			  Rd_word(wpd, &wpu); Box.Width=wpu/47.0f;	// width [mm]
 				
 				// Box content
 			  fseek(wpd, Res.ResourceFilePos+BlockOffset, SEEK_SET);
@@ -717,7 +716,7 @@ void TconvertedPass1_WP6::Box6(void)
           fseek(wpd, 1L, SEEK_CUR);		// Width Flags 1B
           Rd_word(wpd, &wpu);			// Width 2B
           if(wpu!=0)		// Use a new value only when not set from packet #42
-              Box.Width = wpu/47.0;
+              Box.Width = wpu/47.0f;
           }
           //if(OwFlags & 0x0400)
 		// Height flags 1B
@@ -785,7 +784,7 @@ void TconvertedPass1_WP6::Box6(void)
 	if(IDFlags & 0x0800) // ????? This should not occur
 		{
 		fseek(wpd, BlockOffset, SEEK_CUR); //1+???
-		Rd_word(wpd, &wpu);Box.Width=wpu/47.0;
+		Rd_word(wpd, &wpu);Box.Width=wpu/47.0f;
 		}
 
 	pos += SizeOfArea+2;
