@@ -6,7 +6,7 @@
  *              It could be optionally not compiled with WP2LaTeX package.    *
  * licency:     GPL		                                              *
  ******************************************************************************/
-#define RTF_Ver "0.18"
+#define RTF_Ver "0.19"
 // More info about RTF: https://www.biblioscape.com/rtf15_spec.htm
 //TODO: Dodelat znak ? - maze mezeru pred sebou
 //      Autodetekce \section podle xref _TOCxxxxxx
@@ -188,6 +188,7 @@ public:CpTranslator *Unicode;
        void HeaderFooterRTF(unsigned char HFtype);
        void IndexRTF(void);
        void ScanTableFormat(void);
+       bool CellPeak(void);
        };
 TconvertedPass1 *Factory_RTF(void) {return new TconvertedPass1_RTF;}
 FFormatTranslator FormatRTF("RTF",Factory_RTF);
@@ -650,18 +651,18 @@ static int ecPopRtfState(TconvertedPass1_RTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#ecPopRtfState() ");fflush(cq->log);
 #endif
-    SAVE *psaveOld;
-    string s;
+  SAVE *psaveOld;
+  string s;
 
-    if (!cq->psave)
-	{
-	if (cq->err != NULL)
-	   {
-	   cq->perc.Hide();
-	   fprintf(cq->err,_("\nError: Curly brace stack '}' underflow!"));
-	   }
-	return ecStackUnderflow;
-	}
+  if(!cq->psave)
+  {
+    if(cq->err != NULL)
+    {
+      cq->perc.Hide();
+      fprintf(cq->err,_("\nError: Curly brace stack '}' underflow!"));
+    }
+    return ecStackUnderflow;
+  }
 
 /*  if (cq->rds != cq->psave->rds)
 	{		 //The destination specified by rds is coming to a close.
@@ -1343,20 +1344,19 @@ void TconvertedPass1_RTF::IndexRTF(void)
 }
 
 
+/// This is intended to calculata amount of columns of the first row
 void TconvertedPass1_RTF::ScanTableFormat(void)
 {
 #ifdef DEBUG
   fprintf(log,"\n#ScanTableFormat() ");fflush(log);
 #endif
   attribute OldAttr;
-  int CurlyBaraceStack;
+  int CurlyBaraceStack = 1;
   unsigned char OldFlag;
   long BackupPos;
   int cols = 0;
   char *FieldPos = NULL;
 
-  CurlyBaraceStack = 1;
-
   OldFlag = flag;
   flag = Nothing;
   recursion++;
@@ -1382,8 +1382,9 @@ void TconvertedPass1_RTF::ScanTableFormat(void)
 
     if(subby==202 || subby==203 || subby==204)
     {
-      if(Keyword=="par" || Keyword=="pard" ||
-         Keyword=="intbl" || Keyword=="cell" )
+      if(Keyword=="row" ||		// official end of one table row.
+         Keyword=="par" || Keyword=="pard" ||
+         Keyword=="intbl" || Keyword=="cell")
       {
         break;
       }
@@ -1427,13 +1428,97 @@ SkipParsing:
   fseek(wpd, BackupPos, SEEK_SET);
 
   recursion--;
-  if(FieldPos) {free(FieldPos);FieldPos=NULL;}
+
+  if(FieldPos)
+  {
+    if(envir=='b') envir='B';
+    else if(cols>0 && envir!='B')
+    {
+      line_term = 's';   /* Soft return */
+      if(char_on_line == LEAVE_ONE_EMPTY_LINE)  // Left one enpty line for new enviroment.
+      {
+        fputc('%', table);fputc('%', strip);
+        NewLine(this);
+      }
+      if(char_on_line>=CHAR_PRESENT) //  if(char_on_line>=-1)
+      {
+        NewLine(this);
+      }
+      envir='!';
+      fputc('%', table);fputc('%', strip);
+      NewLine(this);
+
+      envir = 'B';
+
+      fprintf(strip, "{|");
+      for(int i=0; i<cols; i++)
+      {
+        if(FieldPos[i]==' ' || FieldPos[i]==0)
+            FieldPos[i] = 'l';
+        fprintf(strip, "%c|", FieldPos[i]);
+      }
+      putc('}', strip);
+      fputs(" \\hline ", strip);
+
+      char_on_line = false;
+      nomore_valid_tabs = false;
+      rownum++;
+      Make_tableentry_attr(this);
+      latex_tabpos = 0;
+    }
+
+    free(FieldPos);FieldPos=NULL;
+  }
 
   strcpy(ObjType, "trowd");
   flag = OldFlag;
 }
 
 
+bool TconvertedPass1_RTF::CellPeak(void)
+{
+bool ValidCell = true;
+long BackupPos;
+const unsigned char OldFlag = flag;
+int CurlyBaraceStack = 1;
+
+  if(toupper(envir)!='B') return false;
+  flag = Nothing;
+  BackupPos = ftell(wpd);
+  recursion++;
+
+  //printf("\n**START**");
+  while(!feof(wpd) && CurlyBaraceStack>=0)
+  {
+    subby = RTFLoadKeyword();
+    if(subby==200) CurlyBaraceStack++;
+    if(subby==201) CurlyBaraceStack--;
+
+    //if(subby==205) fputc(by,stdout);
+
+    if(subby==202 || subby==203 || subby==204)
+    {
+      //printf("\\%s",Keyword());
+      if(Keyword=="row" || Keyword=="trowd" ||
+         Keyword=="par")
+      {
+        ValidCell = false;
+        break;
+      }
+      if(Keyword=="cell") break;
+    }
+  }
+
+  if(CurlyBaraceStack==0) ValidCell=false;
+  //printf("**STOP_%c**", ValidCell?'T':'F');
+  recursion--;
+  fseek(wpd, BackupPos, SEEK_SET);
+  flag = OldFlag;
+return ValidCell;
+}
+
+
+
 static void LanguageRTF(TconvertedPass1_RTF *cq)
 {
  if(!cq->isParam) return;
@@ -1927,17 +2012,30 @@ int KeywordType;
 		  break;
 		  }
 	      if(Keyword=="pard")
-		  {
+	      {
+		if(envir=='b')
+                {
+		  envir='^';		//Ignore enviroments after table
+                  fputc('%', table);
+                  NewLine(this);
+                  char_on_line = FIRST_CHAR_MINIPAGE;	// stronger false;
+		  envir = ' '; 			/*Finish any enviromnet opened*/
+                  break;
+                }
+		if(envir!='B')
+                {  
 		  if(char_on_line) Terminate_Line(this, 'h');	/* Hard return */
 		  envir=' '; 			/*Finish any enviromnet opened*/
 		  break;
-		  }
+                }
+                break;
+	      }
 	      if(Keyword=="pc")
-		  {
+	      {
 		  Parameter="437";
 		  ChangeCpTranslator(this);
 		  break;
-		  }
+	      }
 	      if(Keyword=="pca")
 		  {
 		  Parameter="850";
@@ -2079,15 +2177,31 @@ int KeywordType;
                 ScanTableFormat();
 	        break;
 	      }
+
 	      if(Keyword=="cell")
-              {
-                if(char_on_line==0) char_on_line=-1;
-	        CellTable(this);
+              {             
+                if(CellPeak())
+                {
+                  if(char_on_line==NO_CHAR) char_on_line=JUNK_CHARS;
+	          CellTable(this);
+                }
+                else
+                  fputc(' ',strip);
                 break;
               }
-	      if(Keyword=="row")
+	      if(Keyword=="row")	// Mandatory row definition for every table
               {
+                if(NO_CHAR==char_on_line)
+                {
+                  char_on_line = JUNK_CHARS;
+                }
 		RowTable(this);
+                if(envir=='B') envir='b';
+	        if(psave!=NULL)
+                {
+                  if(psave->pap.envir=='B')
+                      psave->pap.envir = 'b';
+                }
                 break;
               }
 
