@@ -44,15 +44,67 @@ int SavePictureEPS(const char *Name, const Image &Img);
 void CheckOversizedImage(Image *PImg);
 
 
-class ForwardHolder: public VectorObject
+/** Functor class for SVG transform. */
+class TransformSVG: public AbstractTransformXY
 {
 public:
-    ForwardHolder(const char *Key, float NewX, float NewY): x(NewX), y(NewY), KeyHook(Key) {};
+  float_matrix CTM;
+
+  TransformSVG(void): CTM(4,4,(float)0) {CTM(0,0)=CTM(1,1)=CTM(2,2)=CTM(3,3)=1;}
+
+  virtual void ApplyTransform(float &x, float &y) const;
+
+  float TopPBottom;
+};
+
+
+void TransformSVG::ApplyTransform(float &x, float &y) const
+{
+  const float xNew = CTM(0,0)*x + CTM(1,0)*y + CTM(3,0);
+  y = CTM(0,1)*x + CTM(1,1)*y + CTM(3,1);
+  x = xNew;
+}
+
+
+class DefinedObject: public vecPen, public vecBrush
+{
+public:
+    DefinedObject(const string &NewId): id(NewId), PropsSet(0) {};
+
+    VectorList VectList;
+    string id;
+    unsigned char PropsSet;
+
+    typedef enum
+    {
+      EpropFillColor = 1,
+      EpropLineColor = 2
+    }ePropList;
+};
+
+
+class ForwardHolderBase: public VectorObject
+{
+public:
+    ForwardHolderBase(const char *Key): KeyHook(Key) {};
+    //ForwardHolderBase(const string &KeyS): KeyHook(KeyS) {};
+
+    virtual void DoTheJob(const DefinedObject *pDefDObj, VectorList &VectList) = 0;
+
+    string KeyHook;
+};
+
+
+class ForwardHolder: public ForwardHolderBase
+{
+public:
+    ForwardHolder(const char *Key, float NewX, float NewY, uint8_t newFeatures=0xFF): x(NewX), y(NewY), ForwardHolderBase(Key) {};
+    //ForwardHolder(const string &KeyS, float NewX, float NewY, uint8_t newFeatures=0xFF): x(NewX), y(NewY), ForwardHolderBase(KeyS) {};
 
     virtual VectorObject *Duplicate(void) const;
+    virtual void DoTheJob(const DefinedObject *pDefDObj, VectorList &VectList);
 
     float x,y;
-    string KeyHook;
 };
 
 
@@ -62,6 +114,50 @@ VectorObject *ForwardHolder::Duplicate(void) const
 }
 
 
+void ForwardHolder::DoTheJob(const DefinedObject *pDefDObj, VectorList &VectList)
+{
+  if(pDefDObj==NULL) return;
+  VectorObject *Replacement = pDefDObj->VectList.Duplicate();
+  if(this->x!=0 || this->y!=0)
+  {
+    TransformSVG *pTx = new TransformSVG;
+    pTx->CTM(3,0) = this->x;
+    pTx->CTM(3,1) = this->y;
+    Replacement->Transform(*pTx);	// Apply shift x,y operation.
+  }
+  if(!VectList.ReplaceObject(this,Replacement))
+          delete Replacement;		// Not found, should not occur.
+  //delete pObj;			// pObj is either replaced or not found, erase it.
+}
+
+
+class ForwardHolderSolveFill: public ForwardHolderBase
+{
+public:
+    ForwardHolderSolveFill(const char *Key, vecBrush *NewVB): ForwardHolderBase(Key), VB(NewVB)  {};
+
+    virtual void DoTheJob(const DefinedObject *pDefDObj, VectorList &VectList);
+    virtual VectorObject *Duplicate(void) const;
+
+    vecBrush *VB;
+};
+
+
+VectorObject *ForwardHolderSolveFill::Duplicate(void) const
+{
+  return new ForwardHolderSolveFill(KeyHook(),VB);
+}
+
+
+void ForwardHolderSolveFill::DoTheJob(const DefinedObject *pDefDObj, VectorList &VectList)
+{
+ if(pDefDObj==NULL || VB==NULL) return;
+ if((pDefDObj->PropsSet&DefinedObject::EpropFillColor) == 0) return;
+ VB->FillColor = pDefDObj->FillColor;
+ if(VB->BrushStyle==FILL_NONE) VB->BrushStyle=FILL_SOLID;
+}
+
+
 /// Read float value from in memory string.
 /// @param[in,out]	pstr	Pointer to a string to be read.
 /// @param[out]		f	Value read.
@@ -100,27 +196,6 @@ return true;
 inline float DEG2RAD(const float x) {return((x)*(float)M_PI/180.0f);}
 
 
-/** Functor class for SVG transform. */
-class TransformSVG: public AbstractTransformXY
-{
-public:
-  float_matrix CTM;
-
-  TransformSVG(void): CTM(4,4,(float)0) {CTM(0,0)=CTM(1,1)=CTM(2,2)=CTM(3,3)=1;}
-
-  virtual void ApplyTransform(float &x, float &y) const;
-
-  float TopPBottom;
-};
-
-
-void TransformSVG::ApplyTransform(float &x, float &y) const
-{
-  const float xNew = CTM(0,0)*x + CTM(1,0)*y + CTM(3,0);
-  y = CTM(0,1)*x + CTM(1,1)*y + CTM(3,1);
-  x = xNew;
-}
-
 ////////////////////////////////////////////////////
 
 
@@ -135,13 +210,6 @@ public:
 };
 
 
-class DefinedObject
-{
-public:
-    string id;
-    VectorList VectList;
-};
-
 typedef enum
 {
 	SVG_RECT = 130,
@@ -164,14 +232,14 @@ typedef enum
 class TconvertedPass1_SVG: virtual public TconvertedPass1_XML, virtual public TconvertedPass1_Image
      {
 protected:
-     VectorList VectList;
+     VectorList VectList;			///< Main Vector object list.
      doublelist StyleDict;
      PS_State PSS;
      float PositionX, PositionY;
 
      DefinedObject **objs;
      int DObjectCount;
-     ForwardHolder **DelayedObjects;
+     ForwardHolderBase **DelayedObjects;		///< List of mostly empty objects that are simultaneosly stored in the main VectorObject list.
      int DelayedObjCount;
 
      //RGB_Record DefaultLineColor;
@@ -189,6 +257,7 @@ protected:
      AbstractTransformXY *getTransform(void);
      void ClosePathLine(float **pPoints, int & n, bool Close=false, AbstractTransformXY *Tx=NULL);
      void ClosePathCurve(float **pPoints, int & n, bool Close=false, AbstractTransformXY *Tx=NULL);
+     void SolveExtProperty(const char *PropName, vecPen *pVvecPen, vecBrush *pVvecBrush);
 
 public:
      TconvertedPass1_SVG(void);
@@ -197,7 +266,7 @@ public:
      void AddDefine(DefinedObject *pObj);
      void EraseObjCache(void);
      DefinedObject *GetDefine(const char *DefId);
-     void AddDelayedObject(ForwardHolder *pFwdObj);
+     void AddDelayedObject(ForwardHolderBase *pFwdObj);
 
      virtual int Convert_first_pass(void);
      void ProcessKeySVG(void);
@@ -234,7 +303,7 @@ ImplementReader(SVG,".SVG")
    LoadPictureSVG,
    NULL);
 
-#define SVGVersion "0.9"
+#define SVGVersion "0.10"
 
 
 TconvertedPass1_SVG::TconvertedPass1_SVG(void): DelayedObjects(NULL), objs(NULL) 
@@ -299,14 +368,14 @@ void TconvertedPass1_SVG::AddDefine(DefinedObject *pObj)
 }
 
 
-void TconvertedPass1_SVG::AddDelayedObject(ForwardHolder *pFwdObj)
+void TconvertedPass1_SVG::AddDelayedObject(ForwardHolderBase *pFwdObj)
 {
   if(DelayedObjects==NULL)
   {
-    DelayedObjects = (ForwardHolder**)malloc(sizeof(ForwardHolder*));
+    DelayedObjects = (ForwardHolderBase**)malloc(sizeof(ForwardHolderBase*));
     if(DelayedObjects==NULL)
     {
-      //delete pObj;	No delete
+      //delete pObj;	//No delete
       return;
     }
     DelayedObjCount = 1;
@@ -318,10 +387,10 @@ void TconvertedPass1_SVG::AddDelayedObject(ForwardHolder *pFwdObj)
     if(NewObjs==NULL)
     {
       DObjectCount--;
-      //delete pObj;
+      //delete pObj;	//No delete
       return;
     }
-    DelayedObjects = (ForwardHolder**)NewObjs;
+    DelayedObjects = (ForwardHolderBase**)NewObjs;
   }
   DelayedObjects[DelayedObjCount-1] = pFwdObj;
 }
@@ -379,7 +448,7 @@ static SVG_color SVG_colors[] =
 
 
 /** Decode color.
- * @return -1 on failure; 0 when no color specified; 1 Color is OK */
+ * @return -1 on failure; 0 when no color specified; 1 Color is OK; 2 reference to a style */
 int TconvertedPass1_SVG::GetColor(RGB_Record &LineColor, const char *ClrType)
 {
 int i;
@@ -390,6 +459,8 @@ int i;
   if(Payload==NULL) return -1;
 
   if(!strcmp(Payload, "none")) return 0;
+ 
+  if(!strncmp(Payload,"url(#",5)) return 2;
 
   if(Payload[0]=='#' && isxdigit(Payload[1]))
   {
@@ -544,7 +615,7 @@ int i;
 /*
   if(pPen)
   {
-    pPen->LineStyle = DefaultLineStyle;	// Default LineStyle is none.
+    pPen->LineStyle = PSS.LineStyle;	// DefaultLineStyle; // Default LineStyle is none.
     memcpy(&pPen->LineColor, &DefaultLineColor, sizeof(DefaultLineColor));
   }
   if(pBrush)
@@ -1193,17 +1264,18 @@ RGB_Record FillColor;
      //pVecPoly->AttribFromPSS(PSS);
      pVecPoly->FillColor = FillColor;
      //pVecPoly->Outline = true;
+     pVecPoly->AttribFromPSS(PSS);
+     GetStyle(pVecPoly,NULL);
+     if(pVecPoly->BrushStyle==0) pVecPoly->BrushStyle=1;
      pVecLine = pVecPoly;
   }
   else
   {
     pVecLine = new VectorLine(*pPoints,n);
-    //pVecLine->AttribFromPSS(PSS);
+    pVecLine->AttribFromPSS(PSS);
+    GetStyle(pVecLine,NULL);
+    if(pVecLine->LineStyle==0) pVecLine->LineStyle=1;
   }
-  pVecLine->AttribFromPSS(PSS);
-  GetStyle(pVecLine,NULL);		// TODO: This should be reworked.
-
-  if(pVecLine->LineStyle==0) pVecLine->LineStyle=1;
 
   n = 0;
   *pPoints = NULL;
@@ -1248,8 +1320,8 @@ float stroke_width;
 
   VectorCurve *pVecCurve = new VectorCurve(*pPoints, 3*n+1); n=0;
   *pPoints = NULL;
-  GetStyle(pVecCurve,NULL);
-  pVecCurve->AttribFromPSS(PSS);
+  pVecCurve->AttribFromPSS(PSS);	// PSS contains default values
+  GetStyle(pVecCurve,NULL);		// Get style values if exists.
   if(GetProp("stroke-width",stroke_width))
   {
     pVecCurve->PenWidth = stroke_width;
@@ -1263,7 +1335,7 @@ float stroke_width;
             break;
     case 1: if(pVecCurve->BrushStyle==FILL_NONE) pVecCurve->BrushStyle=FILL_SOLID;
 	    //pVecCurve->Filled = true;
-            break;    
+            break;
     //default:
   }
 
@@ -1272,7 +1344,7 @@ float stroke_width;
 }
 
 
-/// <image id="image1JPEG" x="240" y="0" width="240" height="150" xlink:href="data:image/jpg;base64,....
+/// <image id="image1JPEG" x="240" y="0" width="240" height="150" xlink:href="data:image/jpg;base64,
 void TconvertedPass1_SVG::ImageEmbed(void)
 {
 #ifdef DEBUG
@@ -1413,6 +1485,48 @@ float SolveQuadraticPos(const float anch, const float s)
 }
 
 
+void TconvertedPass1_SVG::SolveExtProperty(const char *PropName, vecPen *pVvecPen, vecBrush *pVvecBrush)
+{
+  if((pVvecPen==NULL&&pVvecBrush==NULL) || PropName==NULL) return;
+
+  int i = TAG_Args IN PropName;
+  if(i<0) return;
+  const char * Payload = TAG_Args.Member(i,1);
+  if(Payload==NULL) return;
+
+  if(strncmp(Payload,"url(#",5)) return;
+  Payload += 5;
+  i = strlen(Payload) - 1;
+  while(i>0)
+  {
+    if(Payload[i]==')')
+    {
+      string str(Payload,i);
+      DefinedObject *DFO = GetDefine(str());
+      if(DFO)
+      {
+        if(PropName==FILL_COLOR && pVvecBrush!=NULL &&
+           (DFO->PropsSet&DefinedObject::EpropFillColor)==DefinedObject::EpropFillColor)
+        {
+          pVvecBrush->FillColor = DFO->FillColor;
+          if(pVvecBrush->BrushStyle==FILL_NONE) pVvecBrush->BrushStyle=FILL_SOLID;
+        }
+      }
+      else
+      {
+        if(PropName==FILL_COLOR && pVvecBrush!=NULL)
+        {
+          ForwardHolderSolveFill *pFwdObj = new ForwardHolderSolveFill(str, pVvecBrush);
+          AddDelayedObject(pFwdObj);
+        }
+        return;
+      }
+      break;
+    }
+  }  
+}
+
+
 void TconvertedPass1_SVG::Path(void)
 {
 #ifdef DEBUG
@@ -2105,6 +2219,7 @@ VectorList VectListIn;
           VectorPath *pVectPath = new VectorPath;
           if(pVectPath)
           {
+            pVectPath->AttribFromPSS(PSS);
             GetStyle(pVectPath,pVectPath);
             float stroke_width;
             if(GetProp("stroke-width",stroke_width))
@@ -2117,7 +2232,9 @@ VectorList VectListIn;
                       break;
               case 1: if(pVectPath->BrushStyle==FILL_NONE) pVectPath->BrushStyle=FILL_SOLID;
 	              //pVectPath->Filled = true;
-                      break;    
+                      break;
+              case 2: SolveExtProperty(FILL_COLOR,pVectPath,pVectPath);
+		      break;
               //default:
             }
             GetColor(pVectPath->LineColor);
@@ -2168,7 +2285,7 @@ VectorList VectListIn;
                 break;
         case 1: if(pVectPath->BrushStyle==FILL_NONE) pVectPath->BrushStyle=FILL_SOLID;
                 //pVectPath->Filled = true;
-                break;    
+                break;
         //default:
       }
       GetColor(pVectPath->LineColor);
@@ -2183,12 +2300,12 @@ VectorList VectListIn;
 
   strcpy(ObjType,ObjName+1);
   if(Tx) delete Tx;
-/*
+
 #ifdef _DEBUG
-  FILE*F=fopen("O:\\temp\\38\\dump.txt","wb");
+  FILE*F=fopen("O:\\temp\\39\\dump.txt","wb");
   if(F) {VectList.Dump2File(F);fclose(F);}
 #endif
-*/
+
   return;
 
 ExitErr:
@@ -2330,6 +2447,51 @@ FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
   while(!feof(wpd))
   {
     ReadXMLTag(false);
+
+    if(by==XML_tag && TAG=="<linearGradient>")
+    {
+      DefinedObject *pDefObj = NULL;
+      if((i=TAG_Args IN "id") >= 0)
+      {
+        const char * const Payload = TAG_Args.Member(i,1);
+        if(Payload!=NULL)
+        {
+          pDefObj = new DefinedObject(Payload);
+          if(pDefObj)
+          {
+            if(GetColor(pDefObj->FillColor,FILL_COLOR) == 1)
+                pDefObj->PropsSet |= DefinedObject::EpropFillColor;
+            if(GetColor(pDefObj->LineColor,LINE_COLOR) == 1)
+                pDefObj->PropsSet |= DefinedObject::EpropLineColor;
+          }
+        }
+      }
+
+      recursion++;
+      while(!feof(wpd))
+      {
+        VectList.Swap(pDefObj->VectList);
+        ProcessKeySVG();
+        VectList.Swap(pDefObj->VectList);
+        ReadXMLTag(false);
+
+        if(by==XML_closetag && (TAG=="</defs>" || TAG=="</linearGradient>"))
+            break;
+        if(by==XML_tag && TAG=="<stop>")
+        {          
+          if(GetColor(pDefObj->FillColor, "stop-color") == 1)
+          {          
+            pDefObj->PropsSet |= DefinedObject::EpropFillColor;
+            //if((i=TAG_Args IN "offset") >= 0)		// @TODO: Gradient is not supported yet.
+            //{
+            //}
+          }
+        }
+      }
+      recursion--;
+      if(pDefObj) AddDefine(pDefObj);
+    }
+
     if(by==XML_closetag && TAG=="</defs>")
         break;
 
@@ -2338,10 +2500,9 @@ FloatBBox bbxBk = bbx;	// Defines should not update current bounding box.
       const char * const Payload = TAG_Args.Member(i,1);
       if(Payload!=NULL)
       {
-        DefinedObject *pDefObj = new DefinedObject;
+        DefinedObject *pDefObj = new DefinedObject(Payload);
         if(pDefObj!=NULL)
         {
-          pDefObj->id = Payload;
           VectList.Swap(pDefObj->VectList);
           ProcessKeySVG();
           VectList.Swap(pDefObj->VectList);
@@ -2605,23 +2766,14 @@ void TconvertedPass1_SVG::SolveDelayedObjs(void)
 {
   for(int i=0; i<DelayedObjCount; i++)
   {
-    ForwardHolder *pObj = DelayedObjects[i];
+    ForwardHolderBase *pObj = DelayedObjects[i];
     if(pObj==NULL) continue;
 
     const DefinedObject *pDefDObj = GetDefine(pObj->KeyHook());
     if(pDefDObj)
     {
-      VectorObject *Replacement = pDefDObj->VectList.Duplicate();
-      if(pObj->x!=0 || pObj->y!=0)
-      {
-        TransformSVG *pTx = new TransformSVG;
-        pTx->CTM(3,0) = pObj->x;
-        pTx->CTM(3,1) = pObj->y;
-        Replacement->Transform(*pTx);	// Apply shift x,y operation.
-      }
-      if(!VectList.ReplaceObject(pObj,Replacement))
-          delete Replacement;		// Not found, should not occur.
-      delete pObj;			// pObj is either replacet or not found, erase it.
+      pObj->DoTheJob(pDefDObj,VectList);
+      delete pObj;			// pObj is either replaced or not found, erase it.
     }
     // else pObj could be still referenced.
     DelayedObjects[i] = NULL;
@@ -2667,7 +2819,7 @@ int RetVal = 0;
                 break;
         case 1: if(PSS.FillPattern==FILL_NONE) PSS.FillPattern=FILL_SOLID;
 	        //pVecCurve->Filled = true;
-                break;    
+                break;
         //default:
       }
       break;
