@@ -31,56 +31,56 @@
 
 
 #include "word/wrd_type.h"
-int wvGetSimpleParaBounds (int ver, PAPX_FKP * fkp, U32 * fcFirst,
-	U32 * fcLim, U32 currentfc, BTE * bte, U32 * pos, int nobte, FILE * fd);
+int wvGetSimpleParaBounds (int ver, PAPX_FKP * fkp, uint32_t * fcFirst,
+	uint32_t * fcLim, uint32_t currentfc, BTE * bte, uint32_t * pos, int nobte, FILE * fd);
 
 class TconvertedPass1_WORD:public TconvertedPass1
      {
 public:
      COLEFS *OleFS;
-     WORD ObjectCounter;
-     BYTE CharType;	/* 0-unicode; 1-UTF8; 2-8bit something */
+     uint16_t ObjectCounter;
+     uint8_t CharType;	/* 0-unicode; 1-UTF8; 2-8bit something */
      COLEFILE *Table;
      COLEFILE *Data;
-     BYTE Ver;
+     uint8_t Ver;
      CLX clx;
      FIB fib;
      STSH stsh;
 
      int intable;
-     SWORD **vmerges;
-     SWORD *cellbounds;
-     WORD norows;
+     int16_t **vmerges;
+     int16_t *cellbounds;
+     uint16_t norows;
      int nocellbounds;
 
      SEP sep;
      SED *sed;
-     DWORD *posSedx;
-     DWORD section_intervals;
-     DWORD section_fcLim;
-     DWORD para_fcLim;
+     uint32_t *posSedx;
+     uint32_t section_intervals;
+     uint32_t section_fcLim;
+     uint32_t para_fcLim;
      int para_pendingclose;
      PAPX_FKP para_fkp;
      BTE *btePapx;
-     DWORD *posPapx;
-     DWORD para_intervals;
-     DWORD para_fcFirst;
-     DWORD char_fcFirst;
-     DWORD section_fcFirst;
-     DWORD char_fcLim;
+     uint32_t *posPapx;
+     uint32_t para_intervals;
+     uint32_t para_fcFirst;
+     uint32_t char_fcFirst;
+     uint32_t section_fcFirst;
+     uint32_t char_fcLim;
      CHPX_FKP char_fkp;
      int char_pendingclose;
-     DWORD *posChpx;
+     uint32_t *posChpx;
      BTE *bteChpx;
-     DWORD char_intervals;
+     uint32_t char_intervals;
      CHP achp;
      PAP apap;
      DOP dop;
 		//complex extension
      int cpiece;
 
-     //int (*GetParaBounds) (int ver, PAPX_FKP * fkp, U32 * fcFirst,
-     //		U32 * fcLim, U32 currentfc, BTE * bte, U32 * pos, int nobte, FILE * fd);
+     //int (*GetParaBounds) (int ver, PAPX_FKP * fkp, uint32_t * fcFirst,
+     //		uint32_t * fcLim, uint32_t currentfc, BTE * bte, uint32_t * pos, int nobte, FILE * fd);
 
      virtual int Convert_first_pass(void);
      virtual int Dispatch(int FuncNo, const void *arg);
@@ -98,7 +98,7 @@ static const char *wvAutoCharset(TconvertedPass1_WORD *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#wvAutoCharset() ");fflush(cq->log);
 #endif
-__u16 i = 0;
+uint16_t i = 0;
 int flag;
 const char *ret;
 ret = "iso-8859-15";
@@ -129,9 +129,9 @@ ret = "iso-8859-15";
 int cellCompEQ (void *a, void *b)
 {
     int ret;
-    SWORD *a2, *b2;
-    a2 = (SWORD *) a;
-    b2 = (SWORD *) b;
+    int16_t *a2, *b2;
+    a2 = (int16_t *) a;
+    b2 = (int16_t *) b;
     ret = abs (*a2 - *b2);
     if (ret <= 3)
 	ret = 1;
@@ -143,13 +143,13 @@ int cellCompEQ (void *a, void *b)
 /* allow figures within 3 units of each other to be considered the same*/
 int cellCompLT (void *a, void *b)
 {
-SWORD *a2, *b2;
+int16_t *a2, *b2;
 
     if (cellCompEQ (a, b))
 	return (0);
 
-    a2 = (SWORD *) a;
-    b2 = (SWORD *) b;
+    a2 = (int16_t *) a;
+    b2 = (int16_t *) b;
     return (*a2 < (*b2) + 3);
 }
 
@@ -221,7 +221,7 @@ static void wvSetTableInfo(TconvertedPass1_WORD * ps, TAP * ptap, int no)
     ps->nocellbounds = tree.no_in_tree;
     free(ps->cellbounds);
     if (tree.no_in_tree)
-	ps->cellbounds = (SWORD *)malloc(sizeof (SWORD) * tree.no_in_tree);
+	ps->cellbounds = (int16_t *)malloc(sizeof (int16_t) * tree.no_in_tree);
     else
 	ps->cellbounds = NULL;
 
@@ -229,7 +229,7 @@ static void wvSetTableInfo(TconvertedPass1_WORD * ps, TAP * ptap, int no)
 //    wvTrace (("No in tree is %d\n", tree.no_in_tree));
     while (testn != NULL)
       {
-	  ps->cellbounds[i++] = *((SWORD *) testn->Data);
+	  ps->cellbounds[i++] = *((int16_t *) testn->Data);
 //	  wvTrace (("cellbound are %d\n", ps->cellbounds[i - 1]));
 	  testp = NextNode (&tree, testn);
 	  wvDeleteNode (&tree, testn);
@@ -239,11 +239,11 @@ static void wvSetTableInfo(TconvertedPass1_WORD * ps, TAP * ptap, int no)
 
 //    wvTrace (("end of out\n"));
 
-    ps->vmerges = (SWORD **)malloc(sizeof (SWORD *) * no);
+    ps->vmerges = (int16_t **)malloc(sizeof (int16_t *) * no);
 //    wvTrace (("no of rows is %d", no));
     for (i = 0; i < no; i++)
       {
-	  ps->vmerges[i] = (SWORD *)malloc(sizeof (SWORD) * ptap[i].itcMac);
+	  ps->vmerges[i] = (int16_t *)malloc(sizeof (int16_t) * ptap[i].itcMac);
 //	  wvTrace (("no of cells is %d", ptap[i].itcMac));
 	  for (j = 0; j < ptap[i].itcMac; j++)
 	      ps->vmerges[i][j] = 1;
@@ -295,12 +295,12 @@ static void wvSetTableInfo(TconvertedPass1_WORD * ps, TAP * ptap, int no)
 }
 
 
-static void wvGetFullTableInit(TconvertedPass1_WORD * ps, U32 para_intervals, BTE * btePapx, U32 * posPapx)
+static void wvGetFullTableInit(TconvertedPass1_WORD * ps, uint32_t para_intervals, BTE * btePapx, uint32_t * posPapx)
 {
 PAPX_FKP para_fkp;
-U32 para_fcFirst, para_fcLim = 0xffffffffL;
+uint32_t para_fcFirst, para_fcLim = 0xffffffffL;
 PAP apap;
-U32 i, j = 0;
+uint32_t i, j = 0;
 TAP *test = NULL;
 
     if(ps->intable) return;
@@ -346,13 +346,13 @@ TAP *test = NULL;
 }
 
 
-static void wvGetRowTap (TconvertedPass1_WORD * ps, PAP * dpap, U32 para_intervals,
-	 BTE * btePapx, U32 * posPapx)
+static void wvGetRowTap (TconvertedPass1_WORD * ps, PAP * dpap, uint32_t para_intervals,
+	 BTE * btePapx, uint32_t * posPapx)
 {
 PAPX_FKP para_fkp;
-U32 para_fcFirst, para_fcLim = 0xffffffffL;
+uint32_t para_fcFirst, para_fcLim = 0xffffffffL;
 PAP apap;
-DWORD i;
+uint32_t i;
 
     wvCopyPAP (&apap, dpap);
 
@@ -386,10 +386,10 @@ DWORD i;
 
 
 
-static int wvGetIntervalBounds (U32 * fcFirst, U32 * fcLim, U32 currentfc, U32 * rgfc,
-		     U32 nopos)
+static int wvGetIntervalBounds (uint32_t * fcFirst, uint32_t * fcLim, uint32_t currentfc, uint32_t * rgfc,
+		     uint32_t nopos)
 {
-U32 i = 0;
+uint32_t i = 0;
     while (i < nopos - 1)
       {
 //	  wvTrace (("searching...%x %x %x\n", currentfc, wvNormFC (rgfc[i], NULL), wvNormFC (rgfc[i + 1], NULL)));
@@ -427,18 +427,18 @@ sed.fc must be applied to the local SEP. The process thus far has created a
 SEP that describes what the section properties of the section at the last
 full save.*/
 static int wvGetSimpleSectionBounds(TconvertedPass1_WORD * ps,
-		U32 * fcFirst, U32 * fcLim, U32 cp,
-		SED * sed, U32 * spiece, U32 * posSedx,
-		U32 section_intervals)
+		uint32_t * fcFirst, uint32_t * fcLim, uint32_t cp,
+		SED * sed, uint32_t * spiece, uint32_t * posSedx,
+		uint32_t section_intervals)
 {
 #ifdef DEBUG
   fprintf(ps->log,"\n#wvGetSimpleSectionBounds() ");fflush(ps->log);
 #endif
-U32 i = 0;
+uint32_t i = 0;
 int ret = 0;
 SEPX sepx;
 long pos;
-U32 cpTest = 0, j, dummy;
+uint32_t cpTest = 0, j, dummy;
 
     if (section_intervals == 0)
       {
@@ -504,8 +504,8 @@ paragraph that contains a particular character can be found by
 
 Every character greater than or equal to fcFirst and less than fcLim is part of
 the containing paragraph.*/
-int wvGetSimpleParaBounds (int ver, PAPX_FKP * fkp, U32 * fcFirst,
-	U32 * fcLim, U32 currentfc, BTE * bte, U32 * pos,
+int wvGetSimpleParaBounds (int ver, PAPX_FKP * fkp, uint32_t * fcFirst,
+	uint32_t * fcLim, uint32_t currentfc, BTE * bte, uint32_t * pos,
 	int nobte, FILE * fd)
 {
 BTE entry;
@@ -554,11 +554,11 @@ long currentpos;
 
 
 
-int wvGetSimpleCharBounds(CHPX_FKP * fkp, U32 * fcFirst,
-	       U32 * fcLim, U32 currentcp, CLX * clx, BTE * bte,
-	       U32 * pos, int nobte, FILE * fd)
+int wvGetSimpleCharBounds(CHPX_FKP * fkp, uint32_t * fcFirst,
+	       uint32_t * fcLim, uint32_t currentcp, CLX * clx, BTE * bte,
+	       uint32_t * pos, int nobte, FILE * fd)
 {
-U32 currentfc;
+uint32_t currentfc;
 BTE entry;
 long currentpos;
 
@@ -652,7 +652,7 @@ Readed:
 	   if(i==cq->ObjectCounter)
 	      {
 	      COLEFILE *ColF;
-	      COLEDIR *DirObj;	      
+	      COLEDIR *DirObj;
 
 	      DirObj=cole_opendir_direntry(cde,NULL);
 	      if(DirObj)
@@ -703,7 +703,7 @@ static void ProcessKeyWord(TconvertedPass1_WORD *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#ProcessKeyWord() ");fflush(cq->log);
 #endif
-WORD Wby;
+uint16_t Wby;
 
   if (cq->by == 0)
     {
@@ -784,15 +784,15 @@ static void ApplyCHPChange(TconvertedPass1_WORD *cq)
 	      else AttrOff(cq,aOutline);
 }
 
-static void PieceLoopSimple(TconvertedPass1_WORD *cq,DWORD beginfc, DWORD endfc, int piececount)
+static void PieceLoopSimple(TconvertedPass1_WORD *cq,uint32_t beginfc, uint32_t endfc, int piececount)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#PieceLoopSimple(%d) ",piececount);fflush(cq->log);
 #endif
-DWORD i, spiece;
+uint32_t i, spiece;
 //int section_dirty = 0;
 //int para_dirty=0;
-DWORD begincp, endcp;
+uint32_t begincp, endcp;
 
 	/*lvm007@aha.ru fix antiloop fix*/
  if(piececount>=0)
@@ -935,13 +935,13 @@ DWORD begincp, endcp;
     the local SEP if it is a section sprm.
  3) If pcd.prm.fComplex is 1, pcd.prm.igrpprl is the index of a grpprl in the CLX. 
     If that grpprl contains any section sprms, they should be applied to the local SEP */
-static int wvGetComplexSEP(int ver, SEP * sep, __u32 cpiece, STSH * stsh, CLX * clx)
+static int wvGetComplexSEP(int ver, SEP * sep, uint32_t cpiece, STSH * stsh, CLX * clx)
 {
 int ret = 0;
-__u16 sprm, pos = 0, i = 0;
-__u8 *pointer;
-__u16 index;
-__u8 val;
+uint16_t sprm, pos = 0, i = 0;
+uint8_t *pointer;
+uint16_t index;
+uint8_t val;
 Sprm RetSprm;
 
     if (clx->pcd[cpiece].prm.fComplex == 0)
@@ -953,7 +953,7 @@ Sprm RetSprm;
 #endif
 	  RetSprm =
 	      wvApplySprmFromBucket (ver,
-				     (U16) wvGetrgsprmPrm ( (U16) clx->pcd[cpiece].prm.
+				     (uint16_t) wvGetrgsprmPrm ( (uint16_t) clx->pcd[cpiece].prm.
 						     para.var1.isprm), NULL,
 				     NULL, sep, stsh, pointer, &pos, NULL);
 	  if (RetSprm.sgc == sgcSep)
@@ -980,7 +980,7 @@ Sprm RetSprm;
 		else
 		  {
 		      sprm = bread_8ubit (clx->grpprl[index] + i, &i);
-		      sprm = (U8) wvGetrgsprmWord6 ( (U8) sprm);
+		      sprm = (uint8_t) wvGetrgsprmWord6 ( (uint8_t) sprm);
 		  }
 		pointer = clx->grpprl[index] + i;
 		RetSprm =
@@ -995,11 +995,11 @@ Sprm RetSprm;
 
 
 static int
-  wvGetComplexParafcFirst (int ver, U32 * fcFirst, U32 currentfc,
-			 CLX * clx, BTE * bte, U32 * pos, int nobte,
-			 U32 piece, PAPX_FKP * fkp, FILE * fd)
+  wvGetComplexParafcFirst (int ver, uint32_t * fcFirst, uint32_t currentfc,
+			 CLX * clx, BTE * bte, uint32_t * pos, int nobte,
+			 uint32_t piece, PAPX_FKP * fkp, FILE * fd)
 {
-    U32 fcTest, endfc;
+    uint32_t fcTest, endfc;
     BTE entry;
     fcTest = wvSearchNextLargestFCPAPX_FKP (fkp, currentfc);
 
@@ -1049,10 +1049,10 @@ static int
 }
 
 
-static int wvGetComplexParafcLim (int ver, U32 * fcLim, U32 currentfc, CLX * clx,
-	BTE * bte, U32 * pos, int nobte, U32 piece, PAPX_FKP * fkp, FILE * fd)
+static int wvGetComplexParafcLim (int ver, uint32_t * fcLim, uint32_t currentfc, CLX * clx,
+	BTE * bte, uint32_t * pos, int nobte, uint32_t piece, PAPX_FKP * fkp, FILE * fd)
 {
-U32 fcTest, beginfc;
+uint32_t fcTest, beginfc;
 BTE entry;
 
     *fcLim = 0xffffffffL;
@@ -1144,12 +1144,12 @@ piece, then the character that ends the paragraph is the character
 immediately before the FKP FC.
 */
 static int
- wvGetComplexParaBounds (int ver, PAPX_FKP * fkp, U32 * fcFirst,
-			U32 * fcLim, U32 currentfc, CLX * clx, BTE * bte,
-			U32 * pos, int nobte, U32 piece, FILE * fd)
+ wvGetComplexParaBounds (int ver, PAPX_FKP * fkp, uint32_t * fcFirst,
+			uint32_t * fcLim, uint32_t currentfc, CLX * clx, BTE * bte,
+			uint32_t * pos, int nobte, uint32_t piece, FILE * fd)
 {
     /*
-       U32 currentfc;
+       uint32_t currentfc;
      */
     BTE entry;
     long currentpos;
@@ -1197,15 +1197,15 @@ what the paragraph properties of the paragraph were at the last full save.
 3) If pcd.prm.fComplex is 1, pcd.prm.igrpprl is the index of a grpprl in the
    CLX.  If that grpprl contains any paragraph sprms, they should be applied to
    the local PAP.*/
-static int wvAssembleComplexPAP(int ver, PAP * apap, U32 cpiece, STSH * stsh,
+static int wvAssembleComplexPAP(int ver, PAP * apap, uint32_t cpiece, STSH * stsh,
 		      CLX * clx, FILE * data)
 {
     int ret = 0;
-    U16 sprm, pos = 0, i = 0;
-    U8 sprm8;
-    U8 *pointer;
-    U16 index;
-    U8 val;
+    uint16_t sprm, pos = 0, i = 0;
+    uint8_t sprm8;
+    uint8_t *pointer;
+    uint16_t index;
+    uint8_t val;
     Sprm RetSprm;
 
     if (clx->pcd[cpiece].prm.fComplex == 0)
@@ -1217,7 +1217,7 @@ static int wvAssembleComplexPAP(int ver, PAP * apap, U32 cpiece, STSH * stsh,
 #endif
 	  RetSprm =
 	      wvApplySprmFromBucket (ver,
-				     (U16) wvGetrgsprmPrm ( (U16) clx->pcd[cpiece].prm.
+				     (uint16_t) wvGetrgsprmPrm ( (uint16_t) clx->pcd[cpiece].prm.
 						     para.var1.isprm), apap,
 				     NULL, NULL, stsh, pointer, &pos, data);
 	  if (RetSprm.sgc == sgcPara)
@@ -1241,7 +1241,7 @@ static int wvAssembleComplexPAP(int ver, PAP * apap, U32 cpiece, STSH * stsh,
 		else
 		  {
 		      sprm8 = bread_8ubit (clx->grpprl[index] + i, &i);
-		      sprm = (U16) wvGetrgsprmWord6 (sprm8);
+		      sprm = (uint16_t) wvGetrgsprmWord6 (sprm8);
 //		      wvTrace (("sprm is %x\n", sprm));
 		  }
 		pointer = clx->grpprl[index] + i;
@@ -1256,15 +1256,15 @@ static int wvAssembleComplexPAP(int ver, PAP * apap, U32 cpiece, STSH * stsh,
 }
 
 
-static void PieceLoopComplex(TconvertedPass1_WORD *cq,DWORD beginfc, DWORD endfc, int piececount)
+static void PieceLoopComplex(TconvertedPass1_WORD *cq,uint32_t beginfc, uint32_t endfc, int piececount)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#PieceLoopComplex(%d) ",piececount);fflush(cq->log);
 #endif
-DWORD i, spiece;
+uint32_t i, spiece;
 //int section_dirty = 0;
 //int para_dirty=0;
-DWORD begincp, endcp;
+uint32_t begincp, endcp;
 
  spiece=0;
 	/*lvm007@aha.ru fix antiloop fix*/
@@ -1427,7 +1427,7 @@ int TconvertedPass1_WORD::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_Word() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 string temp_filename;
 
   ObjectCounter=0;
@@ -1569,7 +1569,7 @@ string temp_filename;
 	for(int piececount = 0; piececount < clx.nopcd; piececount++)
 	    {
 	    int ichartype;
-	    DWORD beginfc, endfc;
+	    uint32_t beginfc, endfc;
 
 	    ichartype = wvGetPieceBoundsFC(&beginfc, &endfc, &clx, piececount);
 	    if(ichartype==-1) break;
