@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"4.6"
-#define VersionDate	"25 Apr 2024"  /* day (space) month (space) full year */
+#define VersionWP2L	"4.7"
+#define VersionDate	"2 Jun 2024"  /* day (space) month (space) full year */
 
 
 /** Constants for a flag InputPS */
@@ -581,5 +581,10 @@ typedef enum
 } TStyle;
 
 
+#if defined(__MINGW32__) || defined(__MINGW64__)
+ #ifdef printf
+   #undef printf
+ #endif
+#endif
 
 #endif
